# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v2/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.injective.exchange.v2 import exchange_pb2 as injective_dot_exchange_dot_v2_dot_exchange__pb2
from pyinjective.proto.injective.exchange.v2 import orderbook_pb2 as injective_dot_exchange_dot_v2_dot_orderbook__pb2
from pyinjective.proto.injective.exchange.v2 import market_pb2 as injective_dot_exchange_dot_v2_dot_market__pb2
from pyinjective.proto.injective.exchange.v2 import genesis_pb2 as injective_dot_exchange_dot_v2_dot_genesis__pb2
from pyinjective.proto.injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!injective/exchange/v2/query.proto\x12\x15injective.exchange.v2\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a$injective/exchange/v2/exchange.proto\x1a%injective/exchange/v2/orderbook.proto\x1a\"injective/exchange/v2/market.proto\x1a#injective/exchange/v2/genesis.proto\x1a%injective/oracle/v1beta1/oracle.proto\"O\n\nSubaccount\x12\x16\n\x06trader\x18\x01 \x01(\tR\x06trader\x12)\n\x10subaccount_nonce\x18\x02 \x01(\rR\x0fsubaccountNonce\"`\n\x1cQuerySubaccountOrdersRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\"\xb7\x01\n\x1dQuerySubaccountOrdersResponse\x12I\n\nbuy_orders\x18\x01 \x03(\x0b\x32*.injective.exchange.v2.SubaccountOrderDataR\tbuyOrders\x12K\n\x0bsell_orders\x18\x02 \x03(\x0b\x32*.injective.exchange.v2.SubaccountOrderDataR\nsellOrders\"\xaa\x01\n%SubaccountOrderbookMetadataWithMarket\x12N\n\x08metadata\x18\x01 \x01(\x0b\x32\x32.injective.exchange.v2.SubaccountOrderbookMetadataR\x08metadata\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x14\n\x05isBuy\x18\x03 \x01(\x08R\x05isBuy\"\x1c\n\x1aQueryExchangeParamsRequest\"Z\n\x1bQueryExchangeParamsResponse\x12;\n\x06params\x18\x01 \x01(\x0b\x32\x1d.injective.exchange.v2.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"\x8e\x01\n\x1eQuerySubaccountDepositsRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12G\n\nsubaccount\x18\x02 \x01(\x0b\x32!.injective.exchange.v2.SubaccountB\x04\xc8\xde\x1f\x01R\nsubaccount\"\xe0\x01\n\x1fQuerySubaccountDepositsResponse\x12`\n\x08\x64\x65posits\x18\x01 \x03(\x0b\x32\x44.injective.exchange.v2.QuerySubaccountDepositsResponse.DepositsEntryR\x08\x64\x65posits\x1a[\n\rDepositsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32\x1e.injective.exchange.v2.DepositR\x05value:\x02\x38\x01\"\x1e\n\x1cQueryExchangeBalancesRequest\"a\n\x1dQueryExchangeBalancesResponse\x12@\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32\x1e.injective.exchange.v2.BalanceB\x04\xc8\xde\x1f\x00R\x08\x62\x61lances\"7\n\x1bQueryAggregateVolumeRequest\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\"p\n\x1cQueryAggregateVolumeResponse\x12P\n\x11\x61ggregate_volumes\x18\x01 \x03(\x0b\x32#.injective.exchange.v2.MarketVolumeR\x10\x61ggregateVolumes\"Y\n\x1cQueryAggregateVolumesRequest\x12\x1a\n\x08\x61\x63\x63ounts\x18\x01 \x03(\tR\x08\x61\x63\x63ounts\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds\"\xef\x01\n\x1dQueryAggregateVolumesResponse\x12o\n\x19\x61ggregate_account_volumes\x18\x01 \x03(\x0b\x32\x33.injective.exchange.v2.AggregateAccountVolumeRecordR\x17\x61ggregateAccountVolumes\x12]\n\x18\x61ggregate_market_volumes\x18\x02 \x03(\x0b\x32#.injective.exchange.v2.MarketVolumeR\x16\x61ggregateMarketVolumes\"@\n!QueryAggregateMarketVolumeRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"g\n\"QueryAggregateMarketVolumeResponse\x12\x41\n\x06volume\x18\x01 \x01(\x0b\x32#.injective.exchange.v2.VolumeRecordB\x04\xc8\xde\x1f\x00R\x06volume\"0\n\x18QueryDenomDecimalRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\"5\n\x19QueryDenomDecimalResponse\x12\x18\n\x07\x64\x65\x63imal\x18\x01 \x01(\x04R\x07\x64\x65\x63imal\"3\n\x19QueryDenomDecimalsRequest\x12\x16\n\x06\x64\x65noms\x18\x01 \x03(\tR\x06\x64\x65noms\"o\n\x1aQueryDenomDecimalsResponse\x12Q\n\x0e\x64\x65nom_decimals\x18\x01 \x03(\x0b\x32$.injective.exchange.v2.DenomDecimalsB\x04\xc8\xde\x1f\x00R\rdenomDecimals\"C\n\"QueryAggregateMarketVolumesRequest\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds\"d\n#QueryAggregateMarketVolumesResponse\x12=\n\x07volumes\x18\x01 \x03(\x0b\x32#.injective.exchange.v2.MarketVolumeR\x07volumes\"Z\n\x1dQuerySubaccountDepositRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom\"\\\n\x1eQuerySubaccountDepositResponse\x12:\n\x08\x64\x65posits\x18\x01 \x01(\x0b\x32\x1e.injective.exchange.v2.DepositR\x08\x64\x65posits\"P\n\x17QuerySpotMarketsRequest\x12\x16\n\x06status\x18\x01 \x01(\tR\x06status\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds\"W\n\x18QuerySpotMarketsResponse\x12;\n\x07markets\x18\x01 \x03(\x0b\x32!.injective.exchange.v2.SpotMarketR\x07markets\"5\n\x16QuerySpotMarketRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"T\n\x17QuerySpotMarketResponse\x12\x39\n\x06market\x18\x01 \x01(\x0b\x32!.injective.exchange.v2.SpotMarketR\x06market\"\xd1\x02\n\x19QuerySpotOrderbookRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x14\n\x05limit\x18\x02 \x01(\x04R\x05limit\x12?\n\norder_side\x18\x03 \x01(\x0e\x32 .injective.exchange.v2.OrderSideR\torderSide\x12_\n\x19limit_cumulative_notional\x18\x04 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x17limitCumulativeNotional\x12_\n\x19limit_cumulative_quantity\x18\x05 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x17limitCumulativeQuantity\"\xae\x01\n\x1aQuerySpotOrderbookResponse\x12\x46\n\x10\x62uys_price_level\x18\x01 \x03(\x0b\x32\x1c.injective.exchange.v2.LevelR\x0e\x62uysPriceLevel\x12H\n\x11sells_price_level\x18\x02 \x03(\x0b\x32\x1c.injective.exchange.v2.LevelR\x0fsellsPriceLevel\"\xa3\x01\n\x0e\x46ullSpotMarket\x12\x39\n\x06market\x18\x01 \x01(\x0b\x32!.injective.exchange.v2.SpotMarketR\x06market\x12V\n\x11mid_price_and_tob\x18\x02 \x01(\x0b\x32%.injective.exchange.v2.MidPriceAndTOBB\x04\xc8\xde\x1f\x01R\x0emidPriceAndTob\"\x88\x01\n\x1bQueryFullSpotMarketsRequest\x12\x16\n\x06status\x18\x01 \x01(\tR\x06status\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds\x12\x32\n\x16with_mid_price_and_tob\x18\x03 \x01(\x08R\x12withMidPriceAndTob\"_\n\x1cQueryFullSpotMarketsResponse\x12?\n\x07markets\x18\x01 \x03(\x0b\x32%.injective.exchange.v2.FullSpotMarketR\x07markets\"m\n\x1aQueryFullSpotMarketRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x32\n\x16with_mid_price_and_tob\x18\x02 \x01(\x08R\x12withMidPriceAndTob\"\\\n\x1bQueryFullSpotMarketResponse\x12=\n\x06market\x18\x01 \x01(\x0b\x32%.injective.exchange.v2.FullSpotMarketR\x06market\"\x85\x01\n\x1eQuerySpotOrdersByHashesRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12!\n\x0corder_hashes\x18\x03 \x03(\tR\x0borderHashes\"g\n\x1fQuerySpotOrdersByHashesResponse\x12\x44\n\x06orders\x18\x01 \x03(\x0b\x32,.injective.exchange.v2.TrimmedSpotLimitOrderR\x06orders\"`\n\x1cQueryTraderSpotOrdersRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\"l\n$QueryAccountAddressSpotOrdersRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\'\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\tR\x0e\x61\x63\x63ountAddress\"\x9b\x02\n\x15TrimmedSpotLimitOrder\x12\x39\n\x05price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12?\n\x08quantity\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08quantity\x12?\n\x08\x66illable\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08\x66illable\x12\x14\n\x05isBuy\x18\x04 \x01(\x08R\x05isBuy\x12\x1d\n\norder_hash\x18\x05 \x01(\tR\torderHash\x12\x10\n\x03\x63id\x18\x06 \x01(\tR\x03\x63id\"e\n\x1dQueryTraderSpotOrdersResponse\x12\x44\n\x06orders\x18\x01 \x03(\x0b\x32,.injective.exchange.v2.TrimmedSpotLimitOrderR\x06orders\"m\n%QueryAccountAddressSpotOrdersResponse\x12\x44\n\x06orders\x18\x01 \x03(\x0b\x32,.injective.exchange.v2.TrimmedSpotLimitOrderR\x06orders\"=\n\x1eQuerySpotMidPriceAndTOBRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"\xfb\x01\n\x1fQuerySpotMidPriceAndTOBResponse\x12@\n\tmid_price\x18\x01 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08midPrice\x12I\n\x0e\x62\x65st_buy_price\x18\x02 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0c\x62\x65stBuyPrice\x12K\n\x0f\x62\x65st_sell_price\x18\x03 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\rbestSellPrice\"C\n$QueryDerivativeMidPriceAndTOBRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"\x81\x02\n%QueryDerivativeMidPriceAndTOBResponse\x12@\n\tmid_price\x18\x01 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08midPrice\x12I\n\x0e\x62\x65st_buy_price\x18\x02 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0c\x62\x65stBuyPrice\x12K\n\x0f\x62\x65st_sell_price\x18\x03 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\rbestSellPrice\"\xb5\x01\n\x1fQueryDerivativeOrderbookRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x14\n\x05limit\x18\x02 \x01(\x04R\x05limit\x12_\n\x19limit_cumulative_notional\x18\x03 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x17limitCumulativeNotional\"\xb4\x01\n QueryDerivativeOrderbookResponse\x12\x46\n\x10\x62uys_price_level\x18\x01 \x03(\x0b\x32\x1c.injective.exchange.v2.LevelR\x0e\x62uysPriceLevel\x12H\n\x11sells_price_level\x18\x02 \x03(\x0b\x32\x1c.injective.exchange.v2.LevelR\x0fsellsPriceLevel\"\x97\x03\n.QueryTraderSpotOrdersToCancelUpToAmountRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x44\n\x0b\x62\x61se_amount\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\nbaseAmount\x12\x46\n\x0cquote_amount\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0bquoteAmount\x12G\n\x08strategy\x18\x05 \x01(\x0e\x32+.injective.exchange.v2.CancellationStrategyR\x08strategy\x12L\n\x0freference_price\x18\x06 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0ereferencePrice\"\xd7\x02\n4QueryTraderDerivativeOrdersToCancelUpToAmountRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x46\n\x0cquote_amount\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0bquoteAmount\x12G\n\x08strategy\x18\x04 \x01(\x0e\x32+.injective.exchange.v2.CancellationStrategyR\x08strategy\x12L\n\x0freference_price\x18\x05 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0ereferencePrice\"f\n\"QueryTraderDerivativeOrdersRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\"r\n*QueryAccountAddressDerivativeOrdersRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\'\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\tR\x0e\x61\x63\x63ountAddress\"\xe9\x02\n\x1bTrimmedDerivativeLimitOrder\x12\x39\n\x05price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12?\n\x08quantity\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08quantity\x12;\n\x06margin\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06margin\x12?\n\x08\x66illable\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08\x66illable\x12\x1f\n\x05isBuy\x18\x05 \x01(\x08\x42\t\xea\xde\x1f\x05isBuyR\x05isBuy\x12\x1d\n\norder_hash\x18\x06 \x01(\tR\torderHash\x12\x10\n\x03\x63id\x18\x07 \x01(\tR\x03\x63id\"q\n#QueryTraderDerivativeOrdersResponse\x12J\n\x06orders\x18\x01 \x03(\x0b\x32\x32.injective.exchange.v2.TrimmedDerivativeLimitOrderR\x06orders\"y\n+QueryAccountAddressDerivativeOrdersResponse\x12J\n\x06orders\x18\x01 \x03(\x0b\x32\x32.injective.exchange.v2.TrimmedDerivativeLimitOrderR\x06orders\"\x8b\x01\n$QueryDerivativeOrdersByHashesRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12!\n\x0corder_hashes\x18\x03 \x03(\tR\x0borderHashes\"s\n%QueryDerivativeOrdersByHashesResponse\x12J\n\x06orders\x18\x01 \x03(\x0b\x32\x32.injective.exchange.v2.TrimmedDerivativeLimitOrderR\x06orders\"\x8a\x01\n\x1dQueryDerivativeMarketsRequest\x12\x16\n\x06status\x18\x01 \x01(\tR\x06status\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds\x12\x32\n\x16with_mid_price_and_tob\x18\x03 \x01(\x08R\x12withMidPriceAndTob\"\x88\x01\n\nPriceLevel\x12\x39\n\x05price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12?\n\x08quantity\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08quantity\"\xb5\x01\n\x14PerpetualMarketState\x12K\n\x0bmarket_info\x18\x01 \x01(\x0b\x32*.injective.exchange.v2.PerpetualMarketInfoR\nmarketInfo\x12P\n\x0c\x66unding_info\x18\x02 \x01(\x0b\x32-.injective.exchange.v2.PerpetualMarketFundingR\x0b\x66undingInfo\"\xa6\x03\n\x14\x46ullDerivativeMarket\x12?\n\x06market\x18\x01 \x01(\x0b\x32\'.injective.exchange.v2.DerivativeMarketR\x06market\x12T\n\x0eperpetual_info\x18\x02 \x01(\x0b\x32+.injective.exchange.v2.PerpetualMarketStateH\x00R\rperpetualInfo\x12S\n\x0c\x66utures_info\x18\x03 \x01(\x0b\x32..injective.exchange.v2.ExpiryFuturesMarketInfoH\x00R\x0b\x66uturesInfo\x12\x42\n\nmark_price\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\tmarkPrice\x12V\n\x11mid_price_and_tob\x18\x05 \x01(\x0b\x32%.injective.exchange.v2.MidPriceAndTOBB\x04\xc8\xde\x1f\x01R\x0emidPriceAndTobB\x06\n\x04info\"g\n\x1eQueryDerivativeMarketsResponse\x12\x45\n\x07markets\x18\x01 \x03(\x0b\x32+.injective.exchange.v2.FullDerivativeMarketR\x07markets\";\n\x1cQueryDerivativeMarketRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"d\n\x1dQueryDerivativeMarketResponse\x12\x43\n\x06market\x18\x01 \x01(\x0b\x32+.injective.exchange.v2.FullDerivativeMarketR\x06market\"B\n#QueryDerivativeMarketAddressRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"e\n$QueryDerivativeMarketAddressResponse\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\"G\n QuerySubaccountTradeNonceRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\"<\n\x1dQueryPositionsInMarketRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"g\n\x1eQueryPositionsInMarketResponse\x12\x45\n\x05state\x18\x01 \x03(\x0b\x32).injective.exchange.v2.DerivativePositionB\x04\xc8\xde\x1f\x01R\x05state\"F\n\x1fQuerySubaccountPositionsRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\"j\n&QuerySubaccountPositionInMarketRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\"s\n/QuerySubaccountEffectivePositionInMarketRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\"J\n#QuerySubaccountOrderMetadataRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\"i\n QuerySubaccountPositionsResponse\x12\x45\n\x05state\x18\x01 \x03(\x0b\x32).injective.exchange.v2.DerivativePositionB\x04\xc8\xde\x1f\x00R\x05state\"f\n\'QuerySubaccountPositionInMarketResponse\x12;\n\x05state\x18\x01 \x01(\x0b\x32\x1f.injective.exchange.v2.PositionB\x04\xc8\xde\x1f\x01R\x05state\"\x83\x02\n\x11\x45\x66\x66\x65\x63tivePosition\x12\x17\n\x07is_long\x18\x01 \x01(\x08R\x06isLong\x12?\n\x08quantity\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08quantity\x12\x44\n\x0b\x65ntry_price\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\nentryPrice\x12N\n\x10\x65\x66\x66\x65\x63tive_margin\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0f\x65\x66\x66\x65\x63tiveMargin\"x\n0QuerySubaccountEffectivePositionInMarketResponse\x12\x44\n\x05state\x18\x01 \x01(\x0b\x32(.injective.exchange.v2.EffectivePositionB\x04\xc8\xde\x1f\x01R\x05state\">\n\x1fQueryPerpetualMarketInfoRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"h\n QueryPerpetualMarketInfoResponse\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32*.injective.exchange.v2.PerpetualMarketInfoB\x04\xc8\xde\x1f\x00R\x04info\"B\n#QueryExpiryFuturesMarketInfoRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"p\n$QueryExpiryFuturesMarketInfoResponse\x12H\n\x04info\x18\x01 \x01(\x0b\x32..injective.exchange.v2.ExpiryFuturesMarketInfoB\x04\xc8\xde\x1f\x00R\x04info\"A\n\"QueryPerpetualMarketFundingRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"p\n#QueryPerpetualMarketFundingResponse\x12I\n\x05state\x18\x01 \x01(\x0b\x32-.injective.exchange.v2.PerpetualMarketFundingB\x04\xc8\xde\x1f\x00R\x05state\"\x86\x01\n$QuerySubaccountOrderMetadataResponse\x12^\n\x08metadata\x18\x01 \x03(\x0b\x32<.injective.exchange.v2.SubaccountOrderbookMetadataWithMarketB\x04\xc8\xde\x1f\x00R\x08metadata\"9\n!QuerySubaccountTradeNonceResponse\x12\x14\n\x05nonce\x18\x01 \x01(\rR\x05nonce\"\x19\n\x17QueryModuleStateRequest\"U\n\x18QueryModuleStateResponse\x12\x39\n\x05state\x18\x01 \x01(\x0b\x32#.injective.exchange.v2.GenesisStateR\x05state\"\x17\n\x15QueryPositionsRequest\"_\n\x16QueryPositionsResponse\x12\x45\n\x05state\x18\x01 \x03(\x0b\x32).injective.exchange.v2.DerivativePositionB\x04\xc8\xde\x1f\x00R\x05state\"q\n\x1dQueryTradeRewardPointsRequest\x12\x1a\n\x08\x61\x63\x63ounts\x18\x01 \x03(\tR\x08\x61\x63\x63ounts\x12\x34\n\x16pending_pool_timestamp\x18\x02 \x01(\x03R\x14pendingPoolTimestamp\"\x84\x01\n\x1eQueryTradeRewardPointsResponse\x12\x62\n\x1b\x61\x63\x63ount_trade_reward_points\x18\x01 \x03(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x18\x61\x63\x63ountTradeRewardPoints\"!\n\x1fQueryTradeRewardCampaignRequest\"\xee\x04\n QueryTradeRewardCampaignResponse\x12q\n\x1ctrading_reward_campaign_info\x18\x01 \x01(\x0b\x32\x30.injective.exchange.v2.TradingRewardCampaignInfoR\x19tradingRewardCampaignInfo\x12{\n%trading_reward_pool_campaign_schedule\x18\x02 \x03(\x0b\x32).injective.exchange.v2.CampaignRewardPoolR!tradingRewardPoolCampaignSchedule\x12^\n\x19total_trade_reward_points\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x16totalTradeRewardPoints\x12\x8a\x01\n-pending_trading_reward_pool_campaign_schedule\x18\x04 \x03(\x0b\x32).injective.exchange.v2.CampaignRewardPoolR(pendingTradingRewardPoolCampaignSchedule\x12m\n!pending_total_trade_reward_points\x18\x05 \x03(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x1dpendingTotalTradeRewardPoints\";\n\x1fQueryIsOptedOutOfRewardsRequest\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\"D\n QueryIsOptedOutOfRewardsResponse\x12 \n\x0cis_opted_out\x18\x01 \x01(\x08R\nisOptedOut\"\'\n%QueryOptedOutOfRewardsAccountsRequest\"D\n&QueryOptedOutOfRewardsAccountsResponse\x12\x1a\n\x08\x61\x63\x63ounts\x18\x01 \x03(\tR\x08\x61\x63\x63ounts\">\n\"QueryFeeDiscountAccountInfoRequest\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\"\xdf\x01\n#QueryFeeDiscountAccountInfoResponse\x12\x1d\n\ntier_level\x18\x01 \x01(\x04R\ttierLevel\x12M\n\x0c\x61\x63\x63ount_info\x18\x02 \x01(\x0b\x32*.injective.exchange.v2.FeeDiscountTierInfoR\x0b\x61\x63\x63ountInfo\x12J\n\x0b\x61\x63\x63ount_ttl\x18\x03 \x01(\x0b\x32).injective.exchange.v2.FeeDiscountTierTTLR\naccountTtl\"!\n\x1fQueryFeeDiscountScheduleRequest\"\x82\x01\n QueryFeeDiscountScheduleResponse\x12^\n\x15\x66\x65\x65_discount_schedule\x18\x01 \x01(\x0b\x32*.injective.exchange.v2.FeeDiscountScheduleR\x13\x66\x65\x65\x44iscountSchedule\"@\n\x1dQueryBalanceMismatchesRequest\x12\x1f\n\x0b\x64ust_factor\x18\x01 \x01(\x03R\ndustFactor\"\xa2\x03\n\x0f\x42\x61lanceMismatch\x12\"\n\x0csubaccountId\x18\x01 \x01(\tR\x0csubaccountId\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom\x12\x41\n\tavailable\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\tavailable\x12\x39\n\x05total\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05total\x12\x46\n\x0c\x62\x61lance_hold\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0b\x62\x61lanceHold\x12J\n\x0e\x65xpected_total\x18\x06 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\rexpectedTotal\x12\x43\n\ndifference\x18\x07 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\ndifference\"w\n\x1eQueryBalanceMismatchesResponse\x12U\n\x12\x62\x61lance_mismatches\x18\x01 \x03(\x0b\x32&.injective.exchange.v2.BalanceMismatchR\x11\x62\x61lanceMismatches\"%\n#QueryBalanceWithBalanceHoldsRequest\"\x97\x02\n\x15\x42\x61lanceWithMarginHold\x12\"\n\x0csubaccountId\x18\x01 \x01(\tR\x0csubaccountId\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom\x12\x41\n\tavailable\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\tavailable\x12\x39\n\x05total\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05total\x12\x46\n\x0c\x62\x61lance_hold\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0b\x62\x61lanceHold\"\x91\x01\n$QueryBalanceWithBalanceHoldsResponse\x12i\n\x1a\x62\x61lance_with_balance_holds\x18\x01 \x03(\x0b\x32,.injective.exchange.v2.BalanceWithMarginHoldR\x17\x62\x61lanceWithBalanceHolds\"\'\n%QueryFeeDiscountTierStatisticsRequest\"9\n\rTierStatistic\x12\x12\n\x04tier\x18\x01 \x01(\x04R\x04tier\x12\x14\n\x05\x63ount\x18\x02 \x01(\x04R\x05\x63ount\"n\n&QueryFeeDiscountTierStatisticsResponse\x12\x44\n\nstatistics\x18\x01 \x03(\x0b\x32$.injective.exchange.v2.TierStatisticR\nstatistics\"\x17\n\x15MitoVaultInfosRequest\"\xc4\x01\n\x16MitoVaultInfosResponse\x12)\n\x10master_addresses\x18\x01 \x03(\tR\x0fmasterAddresses\x12\x31\n\x14\x64\x65rivative_addresses\x18\x02 \x03(\tR\x13\x64\x65rivativeAddresses\x12%\n\x0espot_addresses\x18\x03 \x03(\tR\rspotAddresses\x12%\n\x0e\x63w20_addresses\x18\x04 \x03(\tR\rcw20Addresses\"D\n\x1dQueryMarketIDFromVaultRequest\x12#\n\rvault_address\x18\x01 \x01(\tR\x0cvaultAddress\"=\n\x1eQueryMarketIDFromVaultResponse\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"A\n\"QueryHistoricalTradeRecordsRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"o\n#QueryHistoricalTradeRecordsResponse\x12H\n\rtrade_records\x18\x01 \x03(\x0b\x32#.injective.exchange.v2.TradeRecordsR\x0ctradeRecords\"\xb7\x01\n\x13TradeHistoryOptions\x12,\n\x12trade_grouping_sec\x18\x01 \x01(\x04R\x10tradeGroupingSec\x12\x17\n\x07max_age\x18\x02 \x01(\x04R\x06maxAge\x12.\n\x13include_raw_history\x18\x04 \x01(\x08R\x11includeRawHistory\x12)\n\x10include_metadata\x18\x05 \x01(\x08R\x0fincludeMetadata\"\x9b\x01\n\x1cQueryMarketVolatilityRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12^\n\x15trade_history_options\x18\x02 \x01(\x0b\x32*.injective.exchange.v2.TradeHistoryOptionsR\x13tradeHistoryOptions\"\xfe\x01\n\x1dQueryMarketVolatilityResponse\x12?\n\nvolatility\x18\x01 \x01(\tB\x1f\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\nvolatility\x12W\n\x10history_metadata\x18\x02 \x01(\x0b\x32,.injective.oracle.v1beta1.MetadataStatisticsR\x0fhistoryMetadata\x12\x43\n\x0braw_history\x18\x03 \x03(\x0b\x32\".injective.exchange.v2.TradeRecordR\nrawHistory\"3\n\x19QueryBinaryMarketsRequest\x12\x16\n\x06status\x18\x01 \x01(\tR\x06status\"b\n\x1aQueryBinaryMarketsResponse\x12\x44\n\x07markets\x18\x01 \x03(\x0b\x32*.injective.exchange.v2.BinaryOptionsMarketR\x07markets\"q\n-QueryTraderDerivativeConditionalOrdersRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\"\x9e\x03\n!TrimmedDerivativeConditionalOrder\x12\x39\n\x05price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12?\n\x08quantity\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08quantity\x12;\n\x06margin\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06margin\x12G\n\x0ctriggerPrice\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0ctriggerPrice\x12\x1f\n\x05isBuy\x18\x05 \x01(\x08\x42\t\xea\xde\x1f\x05isBuyR\x05isBuy\x12%\n\x07isLimit\x18\x06 \x01(\x08\x42\x0b\xea\xde\x1f\x07isLimitR\x07isLimit\x12\x1d\n\norder_hash\x18\x07 \x01(\tR\torderHash\x12\x10\n\x03\x63id\x18\x08 \x01(\tR\x03\x63id\"\x82\x01\n.QueryTraderDerivativeConditionalOrdersResponse\x12P\n\x06orders\x18\x01 \x03(\x0b\x32\x38.injective.exchange.v2.TrimmedDerivativeConditionalOrderR\x06orders\"<\n\x1dQueryFullSpotOrderbookRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"\x9c\x01\n\x1eQueryFullSpotOrderbookResponse\x12<\n\x04\x42ids\x18\x01 \x03(\x0b\x32(.injective.exchange.v2.TrimmedLimitOrderR\x04\x42ids\x12<\n\x04\x41sks\x18\x02 \x03(\x0b\x32(.injective.exchange.v2.TrimmedLimitOrderR\x04\x41sks\"B\n#QueryFullDerivativeOrderbookRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"\xa2\x01\n$QueryFullDerivativeOrderbookResponse\x12<\n\x04\x42ids\x18\x01 \x03(\x0b\x32(.injective.exchange.v2.TrimmedLimitOrderR\x04\x42ids\x12<\n\x04\x41sks\x18\x02 \x03(\x0b\x32(.injective.exchange.v2.TrimmedLimitOrderR\x04\x41sks\"\xd3\x01\n\x11TrimmedLimitOrder\x12\x39\n\x05price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12?\n\x08quantity\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08quantity\x12\x1d\n\norder_hash\x18\x03 \x01(\tR\torderHash\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\"M\n.QueryMarketAtomicExecutionFeeMultiplierRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"v\n/QueryMarketAtomicExecutionFeeMultiplierResponse\x12\x43\n\nmultiplier\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\nmultiplier\"8\n\x1cQueryActiveStakeGrantRequest\x12\x18\n\x07grantee\x18\x01 \x01(\tR\x07grantee\"\xa9\x01\n\x1dQueryActiveStakeGrantResponse\x12\x38\n\x05grant\x18\x01 \x01(\x0b\x32\".injective.exchange.v2.ActiveGrantR\x05grant\x12N\n\x0f\x65\x66\x66\x65\x63tive_grant\x18\x02 \x01(\x0b\x32%.injective.exchange.v2.EffectiveGrantR\x0e\x65\x66\x66\x65\x63tiveGrant\"T\n\x1eQueryGrantAuthorizationRequest\x12\x18\n\x07granter\x18\x01 \x01(\tR\x07granter\x12\x18\n\x07grantee\x18\x02 \x01(\tR\x07grantee\"X\n\x1fQueryGrantAuthorizationResponse\x12\x35\n\x06\x61mount\x18\x01 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x06\x61mount\";\n\x1fQueryGrantAuthorizationsRequest\x12\x18\n\x07granter\x18\x01 \x01(\tR\x07granter\"\xb2\x01\n QueryGrantAuthorizationsResponse\x12K\n\x12total_grant_amount\x18\x01 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x10totalGrantAmount\x12\x41\n\x06grants\x18\x02 \x03(\x0b\x32).injective.exchange.v2.GrantAuthorizationR\x06grants\"8\n\x19QueryMarketBalanceRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"\\\n\x1aQueryMarketBalanceResponse\x12>\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32$.injective.exchange.v2.MarketBalanceR\x07\x62\x61lance\"\x1c\n\x1aQueryMarketBalancesRequest\"_\n\x1bQueryMarketBalancesResponse\x12@\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32$.injective.exchange.v2.MarketBalanceR\x08\x62\x61lances\"k\n\rMarketBalance\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12=\n\x07\x62\x61lance\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x07\x62\x61lance\"4\n\x1cQueryDenomMinNotionalRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\"\\\n\x1dQueryDenomMinNotionalResponse\x12;\n\x06\x61mount\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06\x61mount\"\x1f\n\x1dQueryDenomMinNotionalsRequest\"y\n\x1eQueryDenomMinNotionalsResponse\x12W\n\x13\x64\x65nom_min_notionals\x18\x01 \x03(\x0b\x32\'.injective.exchange.v2.DenomMinNotionalR\x11\x64\x65nomMinNotionals*4\n\tOrderSide\x12\x14\n\x10Side_Unspecified\x10\x00\x12\x07\n\x03\x42uy\x10\x01\x12\x08\n\x04Sell\x10\x02*V\n\x14\x43\x61ncellationStrategy\x12\x14\n\x10UnspecifiedOrder\x10\x00\x12\x13\n\x0f\x46romWorstToBest\x10\x01\x12\x13\n\x0f\x46romBestToWorst\x10\x02\x32\xe4h\n\x05Query\x12\xd3\x01\n\x15L3DerivativeOrderBook\x12:.injective.exchange.v2.QueryFullDerivativeOrderbookRequest\x1a;.injective.exchange.v2.QueryFullDerivativeOrderbookResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/injective/exchange/v2/derivative/L3OrderBook/{market_id}\x12\xbb\x01\n\x0fL3SpotOrderBook\x12\x34.injective.exchange.v2.QueryFullSpotOrderbookRequest\x1a\x35.injective.exchange.v2.QueryFullSpotOrderbookResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/injective/exchange/v2/spot/L3OrderBook/{market_id}\x12\xab\x01\n\x13QueryExchangeParams\x12\x31.injective.exchange.v2.QueryExchangeParamsRequest\x1a\x32.injective.exchange.v2.QueryExchangeParamsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/injective/exchange/v2/exchangeParams\x12\xbf\x01\n\x12SubaccountDeposits\x12\x35.injective.exchange.v2.QuerySubaccountDepositsRequest\x1a\x36.injective.exchange.v2.QuerySubaccountDepositsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/exchange/v2/exchange/subaccountDeposits\x12\xbb\x01\n\x11SubaccountDeposit\x12\x34.injective.exchange.v2.QuerySubaccountDepositRequest\x1a\x35.injective.exchange.v2.QuerySubaccountDepositResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/injective/exchange/v2/exchange/subaccountDeposit\x12\xb7\x01\n\x10\x45xchangeBalances\x12\x33.injective.exchange.v2.QueryExchangeBalancesRequest\x1a\x34.injective.exchange.v2.QueryExchangeBalancesResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/injective/exchange/v2/exchange/exchangeBalances\x12\xbd\x01\n\x0f\x41ggregateVolume\x12\x32.injective.exchange.v2.QueryAggregateVolumeRequest\x1a\x33.injective.exchange.v2.QueryAggregateVolumeResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/injective/exchange/v2/exchange/aggregateVolume/{account}\x12\xb7\x01\n\x10\x41ggregateVolumes\x12\x33.injective.exchange.v2.QueryAggregateVolumesRequest\x1a\x34.injective.exchange.v2.QueryAggregateVolumesResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/injective/exchange/v2/exchange/aggregateVolumes\x12\xd7\x01\n\x15\x41ggregateMarketVolume\x12\x38.injective.exchange.v2.QueryAggregateMarketVolumeRequest\x1a\x39.injective.exchange.v2.QueryAggregateMarketVolumeResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/injective/exchange/v2/exchange/aggregateMarketVolume/{market_id}\x12\xcf\x01\n\x16\x41ggregateMarketVolumes\x12\x39.injective.exchange.v2.QueryAggregateMarketVolumesRequest\x1a:.injective.exchange.v2.QueryAggregateMarketVolumesResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/injective/exchange/v2/exchange/aggregateMarketVolumes\x12\xb0\x01\n\x0c\x44\x65nomDecimal\x12/.injective.exchange.v2.QueryDenomDecimalRequest\x1a\x30.injective.exchange.v2.QueryDenomDecimalResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/injective/exchange/v2/exchange/denom_decimal/{denom}\x12\xac\x01\n\rDenomDecimals\x12\x30.injective.exchange.v2.QueryDenomDecimalsRequest\x1a\x31.injective.exchange.v2.QueryDenomDecimalsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./injective/exchange/v2/exchange/denom_decimals\x12\x9b\x01\n\x0bSpotMarkets\x12..injective.exchange.v2.QuerySpotMarketsRequest\x1a/.injective.exchange.v2.QuerySpotMarketsResponse\"+\x82\xd3\xe4\x93\x02%\x12#/injective/exchange/v2/spot/markets\x12\xa4\x01\n\nSpotMarket\x12-.injective.exchange.v2.QuerySpotMarketRequest\x1a..injective.exchange.v2.QuerySpotMarketResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/exchange/v2/spot/markets/{market_id}\x12\xac\x01\n\x0f\x46ullSpotMarkets\x12\x32.injective.exchange.v2.QueryFullSpotMarketsRequest\x1a\x33.injective.exchange.v2.QueryFullSpotMarketsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/injective/exchange/v2/spot/full_markets\x12\xb4\x01\n\x0e\x46ullSpotMarket\x12\x31.injective.exchange.v2.QueryFullSpotMarketRequest\x1a\x32.injective.exchange.v2.QueryFullSpotMarketResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/injective/exchange/v2/spot/full_market/{market_id}\x12\xaf\x01\n\rSpotOrderbook\x12\x30.injective.exchange.v2.QuerySpotOrderbookRequest\x1a\x31.injective.exchange.v2.QuerySpotOrderbookResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/injective/exchange/v2/spot/orderbook/{market_id}\x12\xc5\x01\n\x10TraderSpotOrders\x12\x33.injective.exchange.v2.QueryTraderSpotOrdersRequest\x1a\x34.injective.exchange.v2.QueryTraderSpotOrdersResponse\"F\x82\xd3\xe4\x93\x02@\x12>/injective/exchange/v2/spot/orders/{market_id}/{subaccount_id}\x12\xe7\x01\n\x18\x41\x63\x63ountAddressSpotOrders\x12;.injective.exchange.v2.QueryAccountAddressSpotOrdersRequest\x1a<.injective.exchange.v2.QueryAccountAddressSpotOrdersResponse\"P\x82\xd3\xe4\x93\x02J\x12H/injective/exchange/v2/spot/orders/{market_id}/account/{account_address}\x12\xd5\x01\n\x12SpotOrdersByHashes\x12\x35.injective.exchange.v2.QuerySpotOrdersByHashesRequest\x1a\x36.injective.exchange.v2.QuerySpotOrdersByHashesResponse\"P\x82\xd3\xe4\x93\x02J\x12H/injective/exchange/v2/spot/orders_by_hashes/{market_id}/{subaccount_id}\x12\xb4\x01\n\x10SubaccountOrders\x12\x33.injective.exchange.v2.QuerySubaccountOrdersRequest\x1a\x34.injective.exchange.v2.QuerySubaccountOrdersResponse\"5\x82\xd3\xe4\x93\x02/\x12-/injective/exchange/v2/orders/{subaccount_id}\x12\xd8\x01\n\x19TraderSpotTransientOrders\x12\x33.injective.exchange.v2.QueryTraderSpotOrdersRequest\x1a\x34.injective.exchange.v2.QueryTraderSpotOrdersResponse\"P\x82\xd3\xe4\x93\x02J\x12H/injective/exchange/v2/spot/transient_orders/{market_id}/{subaccount_id}\x12\xc6\x01\n\x12SpotMidPriceAndTOB\x12\x35.injective.exchange.v2.QuerySpotMidPriceAndTOBRequest\x1a\x36.injective.exchange.v2.QuerySpotMidPriceAndTOBResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/injective/exchange/v2/spot/mid_price_and_tob/{market_id}\x12\xde\x01\n\x18\x44\x65rivativeMidPriceAndTOB\x12;.injective.exchange.v2.QueryDerivativeMidPriceAndTOBRequest\x1a<.injective.exchange.v2.QueryDerivativeMidPriceAndTOBResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/injective/exchange/v2/derivative/mid_price_and_tob/{market_id}\x12\xc7\x01\n\x13\x44\x65rivativeOrderbook\x12\x36.injective.exchange.v2.QueryDerivativeOrderbookRequest\x1a\x37.injective.exchange.v2.QueryDerivativeOrderbookResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/exchange/v2/derivative/orderbook/{market_id}\x12\xdd\x01\n\x16TraderDerivativeOrders\x12\x39.injective.exchange.v2.QueryTraderDerivativeOrdersRequest\x1a:.injective.exchange.v2.QueryTraderDerivativeOrdersResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/injective/exchange/v2/derivative/orders/{market_id}/{subaccount_id}\x12\xff\x01\n\x1e\x41\x63\x63ountAddressDerivativeOrders\x12\x41.injective.exchange.v2.QueryAccountAddressDerivativeOrdersRequest\x1a\x42.injective.exchange.v2.QueryAccountAddressDerivativeOrdersResponse\"V\x82\xd3\xe4\x93\x02P\x12N/injective/exchange/v2/derivative/orders/{market_id}/account/{account_address}\x12\xed\x01\n\x18\x44\x65rivativeOrdersByHashes\x12;.injective.exchange.v2.QueryDerivativeOrdersByHashesRequest\x1a<.injective.exchange.v2.QueryDerivativeOrdersByHashesResponse\"V\x82\xd3\xe4\x93\x02P\x12N/injective/exchange/v2/derivative/orders_by_hashes/{market_id}/{subaccount_id}\x12\xf0\x01\n\x1fTraderDerivativeTransientOrders\x12\x39.injective.exchange.v2.QueryTraderDerivativeOrdersRequest\x1a:.injective.exchange.v2.QueryTraderDerivativeOrdersResponse\"V\x82\xd3\xe4\x93\x02P\x12N/injective/exchange/v2/derivative/transient_orders/{market_id}/{subaccount_id}\x12\xb3\x01\n\x11\x44\x65rivativeMarkets\x12\x34.injective.exchange.v2.QueryDerivativeMarketsRequest\x1a\x35.injective.exchange.v2.QueryDerivativeMarketsResponse\"1\x82\xd3\xe4\x93\x02+\x12)/injective/exchange/v2/derivative/markets\x12\xbc\x01\n\x10\x44\x65rivativeMarket\x12\x33.injective.exchange.v2.QueryDerivativeMarketRequest\x1a\x34.injective.exchange.v2.QueryDerivativeMarketResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/injective/exchange/v2/derivative/markets/{market_id}\x12\xd8\x01\n\x17\x44\x65rivativeMarketAddress\x12:.injective.exchange.v2.QueryDerivativeMarketAddressRequest\x1a;.injective.exchange.v2.QueryDerivativeMarketAddressResponse\"D\x82\xd3\xe4\x93\x02>\x12</injective/exchange/v2/derivative/market_address/{market_id}\x12\xc2\x01\n\x14SubaccountTradeNonce\x12\x37.injective.exchange.v2.QuerySubaccountTradeNonceRequest\x1a\x38.injective.exchange.v2.QuerySubaccountTradeNonceResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/exchange/v2/exchange/{subaccount_id}\x12\xa3\x01\n\x13\x45xchangeModuleState\x12..injective.exchange.v2.QueryModuleStateRequest\x1a/.injective.exchange.v2.QueryModuleStateResponse\"+\x82\xd3\xe4\x93\x02%\x12#/injective/exchange/v2/module_state\x12\x92\x01\n\tPositions\x12,.injective.exchange.v2.QueryPositionsRequest\x1a-.injective.exchange.v2.QueryPositionsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /injective/exchange/v2/positions\x12\xb6\x01\n\x11PositionsInMarket\x12\x34.injective.exchange.v2.QueryPositionsInMarketRequest\x1a\x35.injective.exchange.v2.QueryPositionsInMarketResponse\"4\x82\xd3\xe4\x93\x02.\x12,/injective/exchange/v2/positions/{market_id}\x12\xc0\x01\n\x13SubaccountPositions\x12\x36.injective.exchange.v2.QuerySubaccountPositionsRequest\x1a\x37.injective.exchange.v2.QuerySubaccountPositionsResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/injective/exchange/v2/positions/{subaccount_id}\x12\xe1\x01\n\x1aSubaccountPositionInMarket\x12=.injective.exchange.v2.QuerySubaccountPositionInMarketRequest\x1a>.injective.exchange.v2.QuerySubaccountPositionInMarketResponse\"D\x82\xd3\xe4\x93\x02>\x12</injective/exchange/v2/positions/{subaccount_id}/{market_id}\x12\x86\x02\n#SubaccountEffectivePositionInMarket\x12\x46.injective.exchange.v2.QuerySubaccountEffectivePositionInMarketRequest\x1aG.injective.exchange.v2.QuerySubaccountEffectivePositionInMarketResponse\"N\x82\xd3\xe4\x93\x02H\x12\x46/injective/exchange/v2/effective_positions/{subaccount_id}/{market_id}\x12\xc8\x01\n\x13PerpetualMarketInfo\x12\x36.injective.exchange.v2.QueryPerpetualMarketInfoRequest\x1a\x37.injective.exchange.v2.QueryPerpetualMarketInfoResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/injective/exchange/v2/perpetual_market_info/{market_id}\x12\xd1\x01\n\x17\x45xpiryFuturesMarketInfo\x12:.injective.exchange.v2.QueryExpiryFuturesMarketInfoRequest\x1a;.injective.exchange.v2.QueryExpiryFuturesMarketInfoResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/injective/exchange/v2/expiry_market_info/{market_id}\x12\xd4\x01\n\x16PerpetualMarketFunding\x12\x39.injective.exchange.v2.QueryPerpetualMarketFundingRequest\x1a:.injective.exchange.v2.QueryPerpetualMarketFundingResponse\"C\x82\xd3\xe4\x93\x02=\x12;/injective/exchange/v2/perpetual_market_funding/{market_id}\x12\xd1\x01\n\x17SubaccountOrderMetadata\x12:.injective.exchange.v2.QuerySubaccountOrderMetadataRequest\x1a;.injective.exchange.v2.QuerySubaccountOrderMetadataResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/injective/exchange/v2/order_metadata/{subaccount_id}\x12\xb4\x01\n\x11TradeRewardPoints\x12\x34.injective.exchange.v2.QueryTradeRewardPointsRequest\x1a\x35.injective.exchange.v2.QueryTradeRewardPointsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/injective/exchange/v2/trade_reward_points\x12\xc3\x01\n\x18PendingTradeRewardPoints\x12\x34.injective.exchange.v2.QueryTradeRewardPointsRequest\x1a\x35.injective.exchange.v2.QueryTradeRewardPointsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/exchange/v2/pending_trade_reward_points\x12\xbc\x01\n\x13TradeRewardCampaign\x12\x36.injective.exchange.v2.QueryTradeRewardCampaignRequest\x1a\x37.injective.exchange.v2.QueryTradeRewardCampaignResponse\"4\x82\xd3\xe4\x93\x02.\x12,/injective/exchange/v2/trade_reward_campaign\x12\xd3\x01\n\x16\x46\x65\x65\x44iscountAccountInfo\x12\x39.injective.exchange.v2.QueryFeeDiscountAccountInfoRequest\x1a:.injective.exchange.v2.QueryFeeDiscountAccountInfoResponse\"B\x82\xd3\xe4\x93\x02<\x12:/injective/exchange/v2/fee_discount_account_info/{account}\x12\xbc\x01\n\x13\x46\x65\x65\x44iscountSchedule\x12\x36.injective.exchange.v2.QueryFeeDiscountScheduleRequest\x1a\x37.injective.exchange.v2.QueryFeeDiscountScheduleResponse\"4\x82\xd3\xe4\x93\x02.\x12,/injective/exchange/v2/fee_discount_schedule\x12\xc1\x01\n\x11\x42\x61lanceMismatches\x12\x34.injective.exchange.v2.QueryBalanceMismatchesRequest\x1a\x35.injective.exchange.v2.QueryBalanceMismatchesResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/exchange/v2/balance_mismatches/{dust_factor}\x12\xce\x01\n\x17\x42\x61lanceWithBalanceHolds\x12:.injective.exchange.v2.QueryBalanceWithBalanceHoldsRequest\x1a;.injective.exchange.v2.QueryBalanceWithBalanceHoldsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/exchange/v2/balances_with_balance_holds\x12\xd0\x01\n\x19\x46\x65\x65\x44iscountTierStatistics\x12<.injective.exchange.v2.QueryFeeDiscountTierStatisticsRequest\x1a=.injective.exchange.v2.QueryFeeDiscountTierStatisticsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./injective/exchange/v2/fee_discount_tier_stats\x12\x9e\x01\n\x0eMitoVaultInfos\x12,.injective.exchange.v2.MitoVaultInfosRequest\x1a-.injective.exchange.v2.MitoVaultInfosResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/injective/exchange/v2/mito_vault_infos\x12\xc5\x01\n\x16QueryMarketIDFromVault\x12\x34.injective.exchange.v2.QueryMarketIDFromVaultRequest\x1a\x35.injective.exchange.v2.QueryMarketIDFromVaultResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/injective/exchange/v2/vault_market_id/{vault_address}\x12\xc8\x01\n\x16HistoricalTradeRecords\x12\x39.injective.exchange.v2.QueryHistoricalTradeRecordsRequest\x1a:.injective.exchange.v2.QueryHistoricalTradeRecordsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/exchange/v2/historical_trade_records\x12\xc8\x01\n\x13IsOptedOutOfRewards\x12\x36.injective.exchange.v2.QueryIsOptedOutOfRewardsRequest\x1a\x37.injective.exchange.v2.QueryIsOptedOutOfRewardsResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/injective/exchange/v2/is_opted_out_of_rewards/{account}\x12\xd6\x01\n\x19OptedOutOfRewardsAccounts\x12<.injective.exchange.v2.QueryOptedOutOfRewardsAccountsRequest\x1a=.injective.exchange.v2.QueryOptedOutOfRewardsAccountsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/injective/exchange/v2/opted_out_of_rewards_accounts\x12\xbb\x01\n\x10MarketVolatility\x12\x33.injective.exchange.v2.QueryMarketVolatilityRequest\x1a\x34.injective.exchange.v2.QueryMarketVolatilityResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/injective/exchange/v2/market_volatility/{market_id}\x12\xb2\x01\n\x14\x42inaryOptionsMarkets\x12\x30.injective.exchange.v2.QueryBinaryMarketsRequest\x1a\x31.injective.exchange.v2.QueryBinaryMarketsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/injective/exchange/v2/binary_options/markets\x12\x8a\x02\n!TraderDerivativeConditionalOrders\x12\x44.injective.exchange.v2.QueryTraderDerivativeConditionalOrdersRequest\x1a\x45.injective.exchange.v2.QueryTraderDerivativeConditionalOrdersResponse\"X\x82\xd3\xe4\x93\x02R\x12P/injective/exchange/v2/derivative/orders/conditional/{market_id}/{subaccount_id}\x12\xef\x01\n\"MarketAtomicExecutionFeeMultiplier\x12\x45.injective.exchange.v2.QueryMarketAtomicExecutionFeeMultiplierRequest\x1a\x46.injective.exchange.v2.QueryMarketAtomicExecutionFeeMultiplierResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/exchange/v2/atomic_order_fee_multiplier\x12\xba\x01\n\x10\x41\x63tiveStakeGrant\x12\x33.injective.exchange.v2.QueryActiveStakeGrantRequest\x1a\x34.injective.exchange.v2.QueryActiveStakeGrantResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/injective/exchange/v2/active_stake_grant/{grantee}\x12\xcb\x01\n\x12GrantAuthorization\x12\x35.injective.exchange.v2.QueryGrantAuthorizationRequest\x1a\x36.injective.exchange.v2.QueryGrantAuthorizationResponse\"F\x82\xd3\xe4\x93\x02@\x12>/injective/exchange/v2/grant_authorization/{granter}/{grantee}\x12\xc5\x01\n\x13GrantAuthorizations\x12\x36.injective.exchange.v2.QueryGrantAuthorizationsRequest\x1a\x37.injective.exchange.v2.QueryGrantAuthorizationsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/injective/exchange/v2/grant_authorizations/{granter}\x12\xaf\x01\n\rMarketBalance\x12\x30.injective.exchange.v2.QueryMarketBalanceRequest\x1a\x31.injective.exchange.v2.QueryMarketBalanceResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/injective/exchange/v2/market_balance/{market_id}\x12\xa7\x01\n\x0eMarketBalances\x12\x31.injective.exchange.v2.QueryMarketBalancesRequest\x1a\x32.injective.exchange.v2.QueryMarketBalancesResponse\".\x82\xd3\xe4\x93\x02(\x12&/injective/exchange/v2/market_balances\x12\xb8\x01\n\x10\x44\x65nomMinNotional\x12\x33.injective.exchange.v2.QueryDenomMinNotionalRequest\x1a\x34.injective.exchange.v2.QueryDenomMinNotionalResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/injective/exchange/v2/denom_min_notional/{denom}\x12\xb4\x01\n\x11\x44\x65nomMinNotionals\x12\x34.injective.exchange.v2.QueryDenomMinNotionalsRequest\x1a\x35.injective.exchange.v2.QueryDenomMinNotionalsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/injective/exchange/v2/denom_min_notionalsB\xf0\x01\n\x19\x63om.injective.exchange.v2B\nQueryProtoP\x01ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types/v2\xa2\x02\x03IEX\xaa\x02\x15Injective.Exchange.V2\xca\x02\x15Injective\\Exchange\\V2\xe2\x02!Injective\\Exchange\\V2\\GPBMetadata\xea\x02\x17Injective::Exchange::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.exchange.v2.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.injective.exchange.v2B\nQueryProtoP\001ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types/v2\242\002\003IEX\252\002\025Injective.Exchange.V2\312\002\025Injective\\Exchange\\V2\342\002!Injective\\Exchange\\V2\\GPBMetadata\352\002\027Injective::Exchange::V2'
  _globals['_QUERYEXCHANGEPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYEXCHANGEPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYSUBACCOUNTDEPOSITSREQUEST'].fields_by_name['subaccount']._loaded_options = None
  _globals['_QUERYSUBACCOUNTDEPOSITSREQUEST'].fields_by_name['subaccount']._serialized_options = b'\310\336\037\001'
  _globals['_QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY']._loaded_options = None
  _globals['_QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY']._serialized_options = b'8\001'
  _globals['_QUERYEXCHANGEBALANCESRESPONSE'].fields_by_name['balances']._loaded_options = None
  _globals['_QUERYEXCHANGEBALANCESRESPONSE'].fields_by_name['balances']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYAGGREGATEMARKETVOLUMERESPONSE'].fields_by_name['volume']._loaded_options = None
  _globals['_QUERYAGGREGATEMARKETVOLUMERESPONSE'].fields_by_name['volume']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYDENOMDECIMALSRESPONSE'].fields_by_name['denom_decimals']._loaded_options = None
  _globals['_QUERYDENOMDECIMALSRESPONSE'].fields_by_name['denom_decimals']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYSPOTORDERBOOKREQUEST'].fields_by_name['limit_cumulative_notional']._loaded_options = None
  _globals['_QUERYSPOTORDERBOOKREQUEST'].fields_by_name['limit_cumulative_notional']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYSPOTORDERBOOKREQUEST'].fields_by_name['limit_cumulative_quantity']._loaded_options = None
  _globals['_QUERYSPOTORDERBOOKREQUEST'].fields_by_name['limit_cumulative_quantity']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_FULLSPOTMARKET'].fields_by_name['mid_price_and_tob']._loaded_options = None
  _globals['_FULLSPOTMARKET'].fields_by_name['mid_price_and_tob']._serialized_options = b'\310\336\037\001'
  _globals['_TRIMMEDSPOTLIMITORDER'].fields_by_name['price']._loaded_options = None
  _globals['_TRIMMEDSPOTLIMITORDER'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDSPOTLIMITORDER'].fields_by_name['quantity']._loaded_options = None
  _globals['_TRIMMEDSPOTLIMITORDER'].fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDSPOTLIMITORDER'].fields_by_name['fillable']._loaded_options = None
  _globals['_TRIMMEDSPOTLIMITORDER'].fields_by_name['fillable']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYSPOTMIDPRICEANDTOBRESPONSE'].fields_by_name['mid_price']._loaded_options = None
  _globals['_QUERYSPOTMIDPRICEANDTOBRESPONSE'].fields_by_name['mid_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYSPOTMIDPRICEANDTOBRESPONSE'].fields_by_name['best_buy_price']._loaded_options = None
  _globals['_QUERYSPOTMIDPRICEANDTOBRESPONSE'].fields_by_name['best_buy_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYSPOTMIDPRICEANDTOBRESPONSE'].fields_by_name['best_sell_price']._loaded_options = None
  _globals['_QUERYSPOTMIDPRICEANDTOBRESPONSE'].fields_by_name['best_sell_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE'].fields_by_name['mid_price']._loaded_options = None
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE'].fields_by_name['mid_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE'].fields_by_name['best_buy_price']._loaded_options = None
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE'].fields_by_name['best_buy_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE'].fields_by_name['best_sell_price']._loaded_options = None
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE'].fields_by_name['best_sell_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYDERIVATIVEORDERBOOKREQUEST'].fields_by_name['limit_cumulative_notional']._loaded_options = None
  _globals['_QUERYDERIVATIVEORDERBOOKREQUEST'].fields_by_name['limit_cumulative_notional']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['base_amount']._loaded_options = None
  _globals['_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['base_amount']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['quote_amount']._loaded_options = None
  _globals['_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['quote_amount']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['reference_price']._loaded_options = None
  _globals['_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['reference_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['quote_amount']._loaded_options = None
  _globals['_QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['quote_amount']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['reference_price']._loaded_options = None
  _globals['_QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['reference_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['price']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['quantity']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['margin']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['margin']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['fillable']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['fillable']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['isBuy']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['isBuy']._serialized_options = b'\352\336\037\005isBuy'
  _globals['_PRICELEVEL'].fields_by_name['price']._loaded_options = None
  _globals['_PRICELEVEL'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PRICELEVEL'].fields_by_name['quantity']._loaded_options = None
  _globals['_PRICELEVEL'].fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_FULLDERIVATIVEMARKET'].fields_by_name['mark_price']._loaded_options = None
  _globals['_FULLDERIVATIVEMARKET'].fields_by_name['mark_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_FULLDERIVATIVEMARKET'].fields_by_name['mid_price_and_tob']._loaded_options = None
  _globals['_FULLDERIVATIVEMARKET'].fields_by_name['mid_price_and_tob']._serialized_options = b'\310\336\037\001'
  _globals['_QUERYPOSITIONSINMARKETRESPONSE'].fields_by_name['state']._loaded_options = None
  _globals['_QUERYPOSITIONSINMARKETRESPONSE'].fields_by_name['state']._serialized_options = b'\310\336\037\001'
  _globals['_QUERYSUBACCOUNTPOSITIONSRESPONSE'].fields_by_name['state']._loaded_options = None
  _globals['_QUERYSUBACCOUNTPOSITIONSRESPONSE'].fields_by_name['state']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE'].fields_by_name['state']._loaded_options = None
  _globals['_QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE'].fields_by_name['state']._serialized_options = b'\310\336\037\001'
  _globals['_EFFECTIVEPOSITION'].fields_by_name['quantity']._loaded_options = None
  _globals['_EFFECTIVEPOSITION'].fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EFFECTIVEPOSITION'].fields_by_name['entry_price']._loaded_options = None
  _globals['_EFFECTIVEPOSITION'].fields_by_name['entry_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EFFECTIVEPOSITION'].fields_by_name['effective_margin']._loaded_options = None
  _globals['_EFFECTIVEPOSITION'].fields_by_name['effective_margin']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE'].fields_by_name['state']._loaded_options = None
  _globals['_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE'].fields_by_name['state']._serialized_options = b'\310\336\037\001'
  _globals['_QUERYPERPETUALMARKETINFORESPONSE'].fields_by_name['info']._loaded_options = None
  _globals['_QUERYPERPETUALMARKETINFORESPONSE'].fields_by_name['info']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYEXPIRYFUTURESMARKETINFORESPONSE'].fields_by_name['info']._loaded_options = None
  _globals['_QUERYEXPIRYFUTURESMARKETINFORESPONSE'].fields_by_name['info']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPERPETUALMARKETFUNDINGRESPONSE'].fields_by_name['state']._loaded_options = None
  _globals['_QUERYPERPETUALMARKETFUNDINGRESPONSE'].fields_by_name['state']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYSUBACCOUNTORDERMETADATARESPONSE'].fields_by_name['metadata']._loaded_options = None
  _globals['_QUERYSUBACCOUNTORDERMETADATARESPONSE'].fields_by_name['metadata']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPOSITIONSRESPONSE'].fields_by_name['state']._loaded_options = None
  _globals['_QUERYPOSITIONSRESPONSE'].fields_by_name['state']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYTRADEREWARDPOINTSRESPONSE'].fields_by_name['account_trade_reward_points']._loaded_options = None
  _globals['_QUERYTRADEREWARDPOINTSRESPONSE'].fields_by_name['account_trade_reward_points']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYTRADEREWARDCAMPAIGNRESPONSE'].fields_by_name['total_trade_reward_points']._loaded_options = None
  _globals['_QUERYTRADEREWARDCAMPAIGNRESPONSE'].fields_by_name['total_trade_reward_points']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYTRADEREWARDCAMPAIGNRESPONSE'].fields_by_name['pending_total_trade_reward_points']._loaded_options = None
  _globals['_QUERYTRADEREWARDCAMPAIGNRESPONSE'].fields_by_name['pending_total_trade_reward_points']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BALANCEMISMATCH'].fields_by_name['available']._loaded_options = None
  _globals['_BALANCEMISMATCH'].fields_by_name['available']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BALANCEMISMATCH'].fields_by_name['total']._loaded_options = None
  _globals['_BALANCEMISMATCH'].fields_by_name['total']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BALANCEMISMATCH'].fields_by_name['balance_hold']._loaded_options = None
  _globals['_BALANCEMISMATCH'].fields_by_name['balance_hold']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BALANCEMISMATCH'].fields_by_name['expected_total']._loaded_options = None
  _globals['_BALANCEMISMATCH'].fields_by_name['expected_total']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BALANCEMISMATCH'].fields_by_name['difference']._loaded_options = None
  _globals['_BALANCEMISMATCH'].fields_by_name['difference']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BALANCEWITHMARGINHOLD'].fields_by_name['available']._loaded_options = None
  _globals['_BALANCEWITHMARGINHOLD'].fields_by_name['available']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BALANCEWITHMARGINHOLD'].fields_by_name['total']._loaded_options = None
  _globals['_BALANCEWITHMARGINHOLD'].fields_by_name['total']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BALANCEWITHMARGINHOLD'].fields_by_name['balance_hold']._loaded_options = None
  _globals['_BALANCEWITHMARGINHOLD'].fields_by_name['balance_hold']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYMARKETVOLATILITYRESPONSE'].fields_by_name['volatility']._loaded_options = None
  _globals['_QUERYMARKETVOLATILITYRESPONSE'].fields_by_name['volatility']._serialized_options = b'\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['price']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['quantity']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['margin']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['margin']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['triggerPrice']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['triggerPrice']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['isBuy']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['isBuy']._serialized_options = b'\352\336\037\005isBuy'
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['isLimit']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['isLimit']._serialized_options = b'\352\336\037\007isLimit'
  _globals['_TRIMMEDLIMITORDER'].fields_by_name['price']._loaded_options = None
  _globals['_TRIMMEDLIMITORDER'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDLIMITORDER'].fields_by_name['quantity']._loaded_options = None
  _globals['_TRIMMEDLIMITORDER'].fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERRESPONSE'].fields_by_name['multiplier']._loaded_options = None
  _globals['_QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERRESPONSE'].fields_by_name['multiplier']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYGRANTAUTHORIZATIONRESPONSE'].fields_by_name['amount']._loaded_options = None
  _globals['_QUERYGRANTAUTHORIZATIONRESPONSE'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_QUERYGRANTAUTHORIZATIONSRESPONSE'].fields_by_name['total_grant_amount']._loaded_options = None
  _globals['_QUERYGRANTAUTHORIZATIONSRESPONSE'].fields_by_name['total_grant_amount']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_MARKETBALANCE'].fields_by_name['balance']._loaded_options = None
  _globals['_MARKETBALANCE'].fields_by_name['balance']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYDENOMMINNOTIONALRESPONSE'].fields_by_name['amount']._loaded_options = None
  _globals['_QUERYDENOMMINNOTIONALRESPONSE'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERY'].methods_by_name['L3DerivativeOrderBook']._loaded_options = None
  _globals['_QUERY'].methods_by_name['L3DerivativeOrderBook']._serialized_options = b'\202\323\344\223\002;\0229/injective/exchange/v2/derivative/L3OrderBook/{market_id}'
  _globals['_QUERY'].methods_by_name['L3SpotOrderBook']._loaded_options = None
  _globals['_QUERY'].methods_by_name['L3SpotOrderBook']._serialized_options = b'\202\323\344\223\0025\0223/injective/exchange/v2/spot/L3OrderBook/{market_id}'
  _globals['_QUERY'].methods_by_name['QueryExchangeParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['QueryExchangeParams']._serialized_options = b'\202\323\344\223\002\'\022%/injective/exchange/v2/exchangeParams'
  _globals['_QUERY'].methods_by_name['SubaccountDeposits']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SubaccountDeposits']._serialized_options = b'\202\323\344\223\0024\0222/injective/exchange/v2/exchange/subaccountDeposits'
  _globals['_QUERY'].methods_by_name['SubaccountDeposit']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SubaccountDeposit']._serialized_options = b'\202\323\344\223\0023\0221/injective/exchange/v2/exchange/subaccountDeposit'
  _globals['_QUERY'].methods_by_name['ExchangeBalances']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ExchangeBalances']._serialized_options = b'\202\323\344\223\0022\0220/injective/exchange/v2/exchange/exchangeBalances'
  _globals['_QUERY'].methods_by_name['AggregateVolume']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AggregateVolume']._serialized_options = b'\202\323\344\223\002;\0229/injective/exchange/v2/exchange/aggregateVolume/{account}'
  _globals['_QUERY'].methods_by_name['AggregateVolumes']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AggregateVolumes']._serialized_options = b'\202\323\344\223\0022\0220/injective/exchange/v2/exchange/aggregateVolumes'
  _globals['_QUERY'].methods_by_name['AggregateMarketVolume']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AggregateMarketVolume']._serialized_options = b'\202\323\344\223\002C\022A/injective/exchange/v2/exchange/aggregateMarketVolume/{market_id}'
  _globals['_QUERY'].methods_by_name['AggregateMarketVolumes']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AggregateMarketVolumes']._serialized_options = b'\202\323\344\223\0028\0226/injective/exchange/v2/exchange/aggregateMarketVolumes'
  _globals['_QUERY'].methods_by_name['DenomDecimal']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomDecimal']._serialized_options = b'\202\323\344\223\0027\0225/injective/exchange/v2/exchange/denom_decimal/{denom}'
  _globals['_QUERY'].methods_by_name['DenomDecimals']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomDecimals']._serialized_options = b'\202\323\344\223\0020\022./injective/exchange/v2/exchange/denom_decimals'
  _globals['_QUERY'].methods_by_name['SpotMarkets']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SpotMarkets']._serialized_options = b'\202\323\344\223\002%\022#/injective/exchange/v2/spot/markets'
  _globals['_QUERY'].methods_by_name['SpotMarket']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SpotMarket']._serialized_options = b'\202\323\344\223\0021\022//injective/exchange/v2/spot/markets/{market_id}'
  _globals['_QUERY'].methods_by_name['FullSpotMarkets']._loaded_options = None
  _globals['_QUERY'].methods_by_name['FullSpotMarkets']._serialized_options = b'\202\323\344\223\002*\022(/injective/exchange/v2/spot/full_markets'
  _globals['_QUERY'].methods_by_name['FullSpotMarket']._loaded_options = None
  _globals['_QUERY'].methods_by_name['FullSpotMarket']._serialized_options = b'\202\323\344\223\0025\0223/injective/exchange/v2/spot/full_market/{market_id}'
  _globals['_QUERY'].methods_by_name['SpotOrderbook']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SpotOrderbook']._serialized_options = b'\202\323\344\223\0023\0221/injective/exchange/v2/spot/orderbook/{market_id}'
  _globals['_QUERY'].methods_by_name['TraderSpotOrders']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TraderSpotOrders']._serialized_options = b'\202\323\344\223\002@\022>/injective/exchange/v2/spot/orders/{market_id}/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['AccountAddressSpotOrders']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AccountAddressSpotOrders']._serialized_options = b'\202\323\344\223\002J\022H/injective/exchange/v2/spot/orders/{market_id}/account/{account_address}'
  _globals['_QUERY'].methods_by_name['SpotOrdersByHashes']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SpotOrdersByHashes']._serialized_options = b'\202\323\344\223\002J\022H/injective/exchange/v2/spot/orders_by_hashes/{market_id}/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['SubaccountOrders']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SubaccountOrders']._serialized_options = b'\202\323\344\223\002/\022-/injective/exchange/v2/orders/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['TraderSpotTransientOrders']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TraderSpotTransientOrders']._serialized_options = b'\202\323\344\223\002J\022H/injective/exchange/v2/spot/transient_orders/{market_id}/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['SpotMidPriceAndTOB']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SpotMidPriceAndTOB']._serialized_options = b'\202\323\344\223\002;\0229/injective/exchange/v2/spot/mid_price_and_tob/{market_id}'
  _globals['_QUERY'].methods_by_name['DerivativeMidPriceAndTOB']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DerivativeMidPriceAndTOB']._serialized_options = b'\202\323\344\223\002A\022?/injective/exchange/v2/derivative/mid_price_and_tob/{market_id}'
  _globals['_QUERY'].methods_by_name['DerivativeOrderbook']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DerivativeOrderbook']._serialized_options = b'\202\323\344\223\0029\0227/injective/exchange/v2/derivative/orderbook/{market_id}'
  _globals['_QUERY'].methods_by_name['TraderDerivativeOrders']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TraderDerivativeOrders']._serialized_options = b'\202\323\344\223\002F\022D/injective/exchange/v2/derivative/orders/{market_id}/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['AccountAddressDerivativeOrders']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AccountAddressDerivativeOrders']._serialized_options = b'\202\323\344\223\002P\022N/injective/exchange/v2/derivative/orders/{market_id}/account/{account_address}'
  _globals['_QUERY'].methods_by_name['DerivativeOrdersByHashes']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DerivativeOrdersByHashes']._serialized_options = b'\202\323\344\223\002P\022N/injective/exchange/v2/derivative/orders_by_hashes/{market_id}/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['TraderDerivativeTransientOrders']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TraderDerivativeTransientOrders']._serialized_options = b'\202\323\344\223\002P\022N/injective/exchange/v2/derivative/transient_orders/{market_id}/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['DerivativeMarkets']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DerivativeMarkets']._serialized_options = b'\202\323\344\223\002+\022)/injective/exchange/v2/derivative/markets'
  _globals['_QUERY'].methods_by_name['DerivativeMarket']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DerivativeMarket']._serialized_options = b'\202\323\344\223\0027\0225/injective/exchange/v2/derivative/markets/{market_id}'
  _globals['_QUERY'].methods_by_name['DerivativeMarketAddress']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DerivativeMarketAddress']._serialized_options = b'\202\323\344\223\002>\022</injective/exchange/v2/derivative/market_address/{market_id}'
  _globals['_QUERY'].methods_by_name['SubaccountTradeNonce']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SubaccountTradeNonce']._serialized_options = b'\202\323\344\223\0021\022//injective/exchange/v2/exchange/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['ExchangeModuleState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ExchangeModuleState']._serialized_options = b'\202\323\344\223\002%\022#/injective/exchange/v2/module_state'
  _globals['_QUERY'].methods_by_name['Positions']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Positions']._serialized_options = b'\202\323\344\223\002\"\022 /injective/exchange/v2/positions'
  _globals['_QUERY'].methods_by_name['PositionsInMarket']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PositionsInMarket']._serialized_options = b'\202\323\344\223\002.\022,/injective/exchange/v2/positions/{market_id}'
  _globals['_QUERY'].methods_by_name['SubaccountPositions']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SubaccountPositions']._serialized_options = b'\202\323\344\223\0022\0220/injective/exchange/v2/positions/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['SubaccountPositionInMarket']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SubaccountPositionInMarket']._serialized_options = b'\202\323\344\223\002>\022</injective/exchange/v2/positions/{subaccount_id}/{market_id}'
  _globals['_QUERY'].methods_by_name['SubaccountEffectivePositionInMarket']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SubaccountEffectivePositionInMarket']._serialized_options = b'\202\323\344\223\002H\022F/injective/exchange/v2/effective_positions/{subaccount_id}/{market_id}'
  _globals['_QUERY'].methods_by_name['PerpetualMarketInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PerpetualMarketInfo']._serialized_options = b'\202\323\344\223\002:\0228/injective/exchange/v2/perpetual_market_info/{market_id}'
  _globals['_QUERY'].methods_by_name['ExpiryFuturesMarketInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ExpiryFuturesMarketInfo']._serialized_options = b'\202\323\344\223\0027\0225/injective/exchange/v2/expiry_market_info/{market_id}'
  _globals['_QUERY'].methods_by_name['PerpetualMarketFunding']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PerpetualMarketFunding']._serialized_options = b'\202\323\344\223\002=\022;/injective/exchange/v2/perpetual_market_funding/{market_id}'
  _globals['_QUERY'].methods_by_name['SubaccountOrderMetadata']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SubaccountOrderMetadata']._serialized_options = b'\202\323\344\223\0027\0225/injective/exchange/v2/order_metadata/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['TradeRewardPoints']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TradeRewardPoints']._serialized_options = b'\202\323\344\223\002,\022*/injective/exchange/v2/trade_reward_points'
  _globals['_QUERY'].methods_by_name['PendingTradeRewardPoints']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PendingTradeRewardPoints']._serialized_options = b'\202\323\344\223\0024\0222/injective/exchange/v2/pending_trade_reward_points'
  _globals['_QUERY'].methods_by_name['TradeRewardCampaign']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TradeRewardCampaign']._serialized_options = b'\202\323\344\223\002.\022,/injective/exchange/v2/trade_reward_campaign'
  _globals['_QUERY'].methods_by_name['FeeDiscountAccountInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['FeeDiscountAccountInfo']._serialized_options = b'\202\323\344\223\002<\022:/injective/exchange/v2/fee_discount_account_info/{account}'
  _globals['_QUERY'].methods_by_name['FeeDiscountSchedule']._loaded_options = None
  _globals['_QUERY'].methods_by_name['FeeDiscountSchedule']._serialized_options = b'\202\323\344\223\002.\022,/injective/exchange/v2/fee_discount_schedule'
  _globals['_QUERY'].methods_by_name['BalanceMismatches']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BalanceMismatches']._serialized_options = b'\202\323\344\223\0029\0227/injective/exchange/v2/balance_mismatches/{dust_factor}'
  _globals['_QUERY'].methods_by_name['BalanceWithBalanceHolds']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BalanceWithBalanceHolds']._serialized_options = b'\202\323\344\223\0024\0222/injective/exchange/v2/balances_with_balance_holds'
  _globals['_QUERY'].methods_by_name['FeeDiscountTierStatistics']._loaded_options = None
  _globals['_QUERY'].methods_by_name['FeeDiscountTierStatistics']._serialized_options = b'\202\323\344\223\0020\022./injective/exchange/v2/fee_discount_tier_stats'
  _globals['_QUERY'].methods_by_name['MitoVaultInfos']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MitoVaultInfos']._serialized_options = b'\202\323\344\223\002)\022\'/injective/exchange/v2/mito_vault_infos'
  _globals['_QUERY'].methods_by_name['QueryMarketIDFromVault']._loaded_options = None
  _globals['_QUERY'].methods_by_name['QueryMarketIDFromVault']._serialized_options = b'\202\323\344\223\0028\0226/injective/exchange/v2/vault_market_id/{vault_address}'
  _globals['_QUERY'].methods_by_name['HistoricalTradeRecords']._loaded_options = None
  _globals['_QUERY'].methods_by_name['HistoricalTradeRecords']._serialized_options = b'\202\323\344\223\0021\022//injective/exchange/v2/historical_trade_records'
  _globals['_QUERY'].methods_by_name['IsOptedOutOfRewards']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IsOptedOutOfRewards']._serialized_options = b'\202\323\344\223\002:\0228/injective/exchange/v2/is_opted_out_of_rewards/{account}'
  _globals['_QUERY'].methods_by_name['OptedOutOfRewardsAccounts']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OptedOutOfRewardsAccounts']._serialized_options = b'\202\323\344\223\0026\0224/injective/exchange/v2/opted_out_of_rewards_accounts'
  _globals['_QUERY'].methods_by_name['MarketVolatility']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MarketVolatility']._serialized_options = b'\202\323\344\223\0026\0224/injective/exchange/v2/market_volatility/{market_id}'
  _globals['_QUERY'].methods_by_name['BinaryOptionsMarkets']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BinaryOptionsMarkets']._serialized_options = b'\202\323\344\223\002/\022-/injective/exchange/v2/binary_options/markets'
  _globals['_QUERY'].methods_by_name['TraderDerivativeConditionalOrders']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TraderDerivativeConditionalOrders']._serialized_options = b'\202\323\344\223\002R\022P/injective/exchange/v2/derivative/orders/conditional/{market_id}/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['MarketAtomicExecutionFeeMultiplier']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MarketAtomicExecutionFeeMultiplier']._serialized_options = b'\202\323\344\223\0024\0222/injective/exchange/v2/atomic_order_fee_multiplier'
  _globals['_QUERY'].methods_by_name['ActiveStakeGrant']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ActiveStakeGrant']._serialized_options = b'\202\323\344\223\0025\0223/injective/exchange/v2/active_stake_grant/{grantee}'
  _globals['_QUERY'].methods_by_name['GrantAuthorization']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GrantAuthorization']._serialized_options = b'\202\323\344\223\002@\022>/injective/exchange/v2/grant_authorization/{granter}/{grantee}'
  _globals['_QUERY'].methods_by_name['GrantAuthorizations']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GrantAuthorizations']._serialized_options = b'\202\323\344\223\0027\0225/injective/exchange/v2/grant_authorizations/{granter}'
  _globals['_QUERY'].methods_by_name['MarketBalance']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MarketBalance']._serialized_options = b'\202\323\344\223\0023\0221/injective/exchange/v2/market_balance/{market_id}'
  _globals['_QUERY'].methods_by_name['MarketBalances']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MarketBalances']._serialized_options = b'\202\323\344\223\002(\022&/injective/exchange/v2/market_balances'
  _globals['_QUERY'].methods_by_name['DenomMinNotional']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomMinNotional']._serialized_options = b'\202\323\344\223\0023\0221/injective/exchange/v2/denom_min_notional/{denom}'
  _globals['_QUERY'].methods_by_name['DenomMinNotionals']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomMinNotionals']._serialized_options = b'\202\323\344\223\002,\022*/injective/exchange/v2/denom_min_notionals'
  _globals['_ORDERSIDE']._serialized_start=18565
  _globals['_ORDERSIDE']._serialized_end=18617
  _globals['_CANCELLATIONSTRATEGY']._serialized_start=18619
  _globals['_CANCELLATIONSTRATEGY']._serialized_end=18705
  _globals['_SUBACCOUNT']._serialized_start=301
  _globals['_SUBACCOUNT']._serialized_end=380
  _globals['_QUERYSUBACCOUNTORDERSREQUEST']._serialized_start=382
  _globals['_QUERYSUBACCOUNTORDERSREQUEST']._serialized_end=478
  _globals['_QUERYSUBACCOUNTORDERSRESPONSE']._serialized_start=481
  _globals['_QUERYSUBACCOUNTORDERSRESPONSE']._serialized_end=664
  _globals['_SUBACCOUNTORDERBOOKMETADATAWITHMARKET']._serialized_start=667
  _globals['_SUBACCOUNTORDERBOOKMETADATAWITHMARKET']._serialized_end=837
  _globals['_QUERYEXCHANGEPARAMSREQUEST']._serialized_start=839
  _globals['_QUERYEXCHANGEPARAMSREQUEST']._serialized_end=867
  _globals['_QUERYEXCHANGEPARAMSRESPONSE']._serialized_start=869
  _globals['_QUERYEXCHANGEPARAMSRESPONSE']._serialized_end=959
  _globals['_QUERYSUBACCOUNTDEPOSITSREQUEST']._serialized_start=962
  _globals['_QUERYSUBACCOUNTDEPOSITSREQUEST']._serialized_end=1104
  _globals['_QUERYSUBACCOUNTDEPOSITSRESPONSE']._serialized_start=1107
  _globals['_QUERYSUBACCOUNTDEPOSITSRESPONSE']._serialized_end=1331
  _globals['_QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY']._serialized_start=1240
  _globals['_QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY']._serialized_end=1331
  _globals['_QUERYEXCHANGEBALANCESREQUEST']._serialized_start=1333
  _globals['_QUERYEXCHANGEBALANCESREQUEST']._serialized_end=1363
  _globals['_QUERYEXCHANGEBALANCESRESPONSE']._serialized_start=1365
  _globals['_QUERYEXCHANGEBALANCESRESPONSE']._serialized_end=1462
  _globals['_QUERYAGGREGATEVOLUMEREQUEST']._serialized_start=1464
  _globals['_QUERYAGGREGATEVOLUMEREQUEST']._serialized_end=1519
  _globals['_QUERYAGGREGATEVOLUMERESPONSE']._serialized_start=1521
  _globals['_QUERYAGGREGATEVOLUMERESPONSE']._serialized_end=1633
  _globals['_QUERYAGGREGATEVOLUMESREQUEST']._serialized_start=1635
  _globals['_QUERYAGGREGATEVOLUMESREQUEST']._serialized_end=1724
  _globals['_QUERYAGGREGATEVOLUMESRESPONSE']._serialized_start=1727
  _globals['_QUERYAGGREGATEVOLUMESRESPONSE']._serialized_end=1966
  _globals['_QUERYAGGREGATEMARKETVOLUMEREQUEST']._serialized_start=1968
  _globals['_QUERYAGGREGATEMARKETVOLUMEREQUEST']._serialized_end=2032
  _globals['_QUERYAGGREGATEMARKETVOLUMERESPONSE']._serialized_start=2034
  _globals['_QUERYAGGREGATEMARKETVOLUMERESPONSE']._serialized_end=2137
  _globals['_QUERYDENOMDECIMALREQUEST']._serialized_start=2139
  _globals['_QUERYDENOMDECIMALREQUEST']._serialized_end=2187
  _globals['_QUERYDENOMDECIMALRESPONSE']._serialized_start=2189
  _globals['_QUERYDENOMDECIMALRESPONSE']._serialized_end=2242
  _globals['_QUERYDENOMDECIMALSREQUEST']._serialized_start=2244
  _globals['_QUERYDENOMDECIMALSREQUEST']._serialized_end=2295
  _globals['_QUERYDENOMDECIMALSRESPONSE']._serialized_start=2297
  _globals['_QUERYDENOMDECIMALSRESPONSE']._serialized_end=2408
  _globals['_QUERYAGGREGATEMARKETVOLUMESREQUEST']._serialized_start=2410
  _globals['_QUERYAGGREGATEMARKETVOLUMESREQUEST']._serialized_end=2477
  _globals['_QUERYAGGREGATEMARKETVOLUMESRESPONSE']._serialized_start=2479
  _globals['_QUERYAGGREGATEMARKETVOLUMESRESPONSE']._serialized_end=2579
  _globals['_QUERYSUBACCOUNTDEPOSITREQUEST']._serialized_start=2581
  _globals['_QUERYSUBACCOUNTDEPOSITREQUEST']._serialized_end=2671
  _globals['_QUERYSUBACCOUNTDEPOSITRESPONSE']._serialized_start=2673
  _globals['_QUERYSUBACCOUNTDEPOSITRESPONSE']._serialized_end=2765
  _globals['_QUERYSPOTMARKETSREQUEST']._serialized_start=2767
  _globals['_QUERYSPOTMARKETSREQUEST']._serialized_end=2847
  _globals['_QUERYSPOTMARKETSRESPONSE']._serialized_start=2849
  _globals['_QUERYSPOTMARKETSRESPONSE']._serialized_end=2936
  _globals['_QUERYSPOTMARKETREQUEST']._serialized_start=2938
  _globals['_QUERYSPOTMARKETREQUEST']._serialized_end=2991
  _globals['_QUERYSPOTMARKETRESPONSE']._serialized_start=2993
  _globals['_QUERYSPOTMARKETRESPONSE']._serialized_end=3077
  _globals['_QUERYSPOTORDERBOOKREQUEST']._serialized_start=3080
  _globals['_QUERYSPOTORDERBOOKREQUEST']._serialized_end=3417
  _globals['_QUERYSPOTORDERBOOKRESPONSE']._serialized_start=3420
  _globals['_QUERYSPOTORDERBOOKRESPONSE']._serialized_end=3594
  _globals['_FULLSPOTMARKET']._serialized_start=3597
  _globals['_FULLSPOTMARKET']._serialized_end=3760
  _globals['_QUERYFULLSPOTMARKETSREQUEST']._serialized_start=3763
  _globals['_QUERYFULLSPOTMARKETSREQUEST']._serialized_end=3899
  _globals['_QUERYFULLSPOTMARKETSRESPONSE']._serialized_start=3901
  _globals['_QUERYFULLSPOTMARKETSRESPONSE']._serialized_end=3996
  _globals['_QUERYFULLSPOTMARKETREQUEST']._serialized_start=3998
  _globals['_QUERYFULLSPOTMARKETREQUEST']._serialized_end=4107
  _globals['_QUERYFULLSPOTMARKETRESPONSE']._serialized_start=4109
  _globals['_QUERYFULLSPOTMARKETRESPONSE']._serialized_end=4201
  _globals['_QUERYSPOTORDERSBYHASHESREQUEST']._serialized_start=4204
  _globals['_QUERYSPOTORDERSBYHASHESREQUEST']._serialized_end=4337
  _globals['_QUERYSPOTORDERSBYHASHESRESPONSE']._serialized_start=4339
  _globals['_QUERYSPOTORDERSBYHASHESRESPONSE']._serialized_end=4442
  _globals['_QUERYTRADERSPOTORDERSREQUEST']._serialized_start=4444
  _globals['_QUERYTRADERSPOTORDERSREQUEST']._serialized_end=4540
  _globals['_QUERYACCOUNTADDRESSSPOTORDERSREQUEST']._serialized_start=4542
  _globals['_QUERYACCOUNTADDRESSSPOTORDERSREQUEST']._serialized_end=4650
  _globals['_TRIMMEDSPOTLIMITORDER']._serialized_start=4653
  _globals['_TRIMMEDSPOTLIMITORDER']._serialized_end=4936
  _globals['_QUERYTRADERSPOTORDERSRESPONSE']._serialized_start=4938
  _globals['_QUERYTRADERSPOTORDERSRESPONSE']._serialized_end=5039
  _globals['_QUERYACCOUNTADDRESSSPOTORDERSRESPONSE']._serialized_start=5041
  _globals['_QUERYACCOUNTADDRESSSPOTORDERSRESPONSE']._serialized_end=5150
  _globals['_QUERYSPOTMIDPRICEANDTOBREQUEST']._serialized_start=5152
  _globals['_QUERYSPOTMIDPRICEANDTOBREQUEST']._serialized_end=5213
  _globals['_QUERYSPOTMIDPRICEANDTOBRESPONSE']._serialized_start=5216
  _globals['_QUERYSPOTMIDPRICEANDTOBRESPONSE']._serialized_end=5467
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBREQUEST']._serialized_start=5469
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBREQUEST']._serialized_end=5536
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE']._serialized_start=5539
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE']._serialized_end=5796
  _globals['_QUERYDERIVATIVEORDERBOOKREQUEST']._serialized_start=5799
  _globals['_QUERYDERIVATIVEORDERBOOKREQUEST']._serialized_end=5980
  _globals['_QUERYDERIVATIVEORDERBOOKRESPONSE']._serialized_start=5983
  _globals['_QUERYDERIVATIVEORDERBOOKRESPONSE']._serialized_end=6163
  _globals['_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST']._serialized_start=6166
  _globals['_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST']._serialized_end=6573
  _globals['_QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST']._serialized_start=6576
  _globals['_QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST']._serialized_end=6919
  _globals['_QUERYTRADERDERIVATIVEORDERSREQUEST']._serialized_start=6921
  _globals['_QUERYTRADERDERIVATIVEORDERSREQUEST']._serialized_end=7023
  _globals['_QUERYACCOUNTADDRESSDERIVATIVEORDERSREQUEST']._serialized_start=7025
  _globals['_QUERYACCOUNTADDRESSDERIVATIVEORDERSREQUEST']._serialized_end=7139
  _globals['_TRIMMEDDERIVATIVELIMITORDER']._serialized_start=7142
  _globals['_TRIMMEDDERIVATIVELIMITORDER']._serialized_end=7503
  _globals['_QUERYTRADERDERIVATIVEORDERSRESPONSE']._serialized_start=7505
  _globals['_QUERYTRADERDERIVATIVEORDERSRESPONSE']._serialized_end=7618
  _globals['_QUERYACCOUNTADDRESSDERIVATIVEORDERSRESPONSE']._serialized_start=7620
  _globals['_QUERYACCOUNTADDRESSDERIVATIVEORDERSRESPONSE']._serialized_end=7741
  _globals['_QUERYDERIVATIVEORDERSBYHASHESREQUEST']._serialized_start=7744
  _globals['_QUERYDERIVATIVEORDERSBYHASHESREQUEST']._serialized_end=7883
  _globals['_QUERYDERIVATIVEORDERSBYHASHESRESPONSE']._serialized_start=7885
  _globals['_QUERYDERIVATIVEORDERSBYHASHESRESPONSE']._serialized_end=8000
  _globals['_QUERYDERIVATIVEMARKETSREQUEST']._serialized_start=8003
  _globals['_QUERYDERIVATIVEMARKETSREQUEST']._serialized_end=8141
  _globals['_PRICELEVEL']._serialized_start=8144
  _globals['_PRICELEVEL']._serialized_end=8280
  _globals['_PERPETUALMARKETSTATE']._serialized_start=8283
  _globals['_PERPETUALMARKETSTATE']._serialized_end=8464
  _globals['_FULLDERIVATIVEMARKET']._serialized_start=8467
  _globals['_FULLDERIVATIVEMARKET']._serialized_end=8889
  _globals['_QUERYDERIVATIVEMARKETSRESPONSE']._serialized_start=8891
  _globals['_QUERYDERIVATIVEMARKETSRESPONSE']._serialized_end=8994
  _globals['_QUERYDERIVATIVEMARKETREQUEST']._serialized_start=8996
  _globals['_QUERYDERIVATIVEMARKETREQUEST']._serialized_end=9055
  _globals['_QUERYDERIVATIVEMARKETRESPONSE']._serialized_start=9057
  _globals['_QUERYDERIVATIVEMARKETRESPONSE']._serialized_end=9157
  _globals['_QUERYDERIVATIVEMARKETADDRESSREQUEST']._serialized_start=9159
  _globals['_QUERYDERIVATIVEMARKETADDRESSREQUEST']._serialized_end=9225
  _globals['_QUERYDERIVATIVEMARKETADDRESSRESPONSE']._serialized_start=9227
  _globals['_QUERYDERIVATIVEMARKETADDRESSRESPONSE']._serialized_end=9328
  _globals['_QUERYSUBACCOUNTTRADENONCEREQUEST']._serialized_start=9330
  _globals['_QUERYSUBACCOUNTTRADENONCEREQUEST']._serialized_end=9401
  _globals['_QUERYPOSITIONSINMARKETREQUEST']._serialized_start=9403
  _globals['_QUERYPOSITIONSINMARKETREQUEST']._serialized_end=9463
  _globals['_QUERYPOSITIONSINMARKETRESPONSE']._serialized_start=9465
  _globals['_QUERYPOSITIONSINMARKETRESPONSE']._serialized_end=9568
  _globals['_QUERYSUBACCOUNTPOSITIONSREQUEST']._serialized_start=9570
  _globals['_QUERYSUBACCOUNTPOSITIONSREQUEST']._serialized_end=9640
  _globals['_QUERYSUBACCOUNTPOSITIONINMARKETREQUEST']._serialized_start=9642
  _globals['_QUERYSUBACCOUNTPOSITIONINMARKETREQUEST']._serialized_end=9748
  _globals['_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETREQUEST']._serialized_start=9750
  _globals['_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETREQUEST']._serialized_end=9865
  _globals['_QUERYSUBACCOUNTORDERMETADATAREQUEST']._serialized_start=9867
  _globals['_QUERYSUBACCOUNTORDERMETADATAREQUEST']._serialized_end=9941
  _globals['_QUERYSUBACCOUNTPOSITIONSRESPONSE']._serialized_start=9943
  _globals['_QUERYSUBACCOUNTPOSITIONSRESPONSE']._serialized_end=10048
  _globals['_QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE']._serialized_start=10050
  _globals['_QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE']._serialized_end=10152
  _globals['_EFFECTIVEPOSITION']._serialized_start=10155
  _globals['_EFFECTIVEPOSITION']._serialized_end=10414
  _globals['_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE']._serialized_start=10416
  _globals['_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE']._serialized_end=10536
  _globals['_QUERYPERPETUALMARKETINFOREQUEST']._serialized_start=10538
  _globals['_QUERYPERPETUALMARKETINFOREQUEST']._serialized_end=10600
  _globals['_QUERYPERPETUALMARKETINFORESPONSE']._serialized_start=10602
  _globals['_QUERYPERPETUALMARKETINFORESPONSE']._serialized_end=10706
  _globals['_QUERYEXPIRYFUTURESMARKETINFOREQUEST']._serialized_start=10708
  _globals['_QUERYEXPIRYFUTURESMARKETINFOREQUEST']._serialized_end=10774
  _globals['_QUERYEXPIRYFUTURESMARKETINFORESPONSE']._serialized_start=10776
  _globals['_QUERYEXPIRYFUTURESMARKETINFORESPONSE']._serialized_end=10888
  _globals['_QUERYPERPETUALMARKETFUNDINGREQUEST']._serialized_start=10890
  _globals['_QUERYPERPETUALMARKETFUNDINGREQUEST']._serialized_end=10955
  _globals['_QUERYPERPETUALMARKETFUNDINGRESPONSE']._serialized_start=10957
  _globals['_QUERYPERPETUALMARKETFUNDINGRESPONSE']._serialized_end=11069
  _globals['_QUERYSUBACCOUNTORDERMETADATARESPONSE']._serialized_start=11072
  _globals['_QUERYSUBACCOUNTORDERMETADATARESPONSE']._serialized_end=11206
  _globals['_QUERYSUBACCOUNTTRADENONCERESPONSE']._serialized_start=11208
  _globals['_QUERYSUBACCOUNTTRADENONCERESPONSE']._serialized_end=11265
  _globals['_QUERYMODULESTATEREQUEST']._serialized_start=11267
  _globals['_QUERYMODULESTATEREQUEST']._serialized_end=11292
  _globals['_QUERYMODULESTATERESPONSE']._serialized_start=11294
  _globals['_QUERYMODULESTATERESPONSE']._serialized_end=11379
  _globals['_QUERYPOSITIONSREQUEST']._serialized_start=11381
  _globals['_QUERYPOSITIONSREQUEST']._serialized_end=11404
  _globals['_QUERYPOSITIONSRESPONSE']._serialized_start=11406
  _globals['_QUERYPOSITIONSRESPONSE']._serialized_end=11501
  _globals['_QUERYTRADEREWARDPOINTSREQUEST']._serialized_start=11503
  _globals['_QUERYTRADEREWARDPOINTSREQUEST']._serialized_end=11616
  _globals['_QUERYTRADEREWARDPOINTSRESPONSE']._serialized_start=11619
  _globals['_QUERYTRADEREWARDPOINTSRESPONSE']._serialized_end=11751
  _globals['_QUERYTRADEREWARDCAMPAIGNREQUEST']._serialized_start=11753
  _globals['_QUERYTRADEREWARDCAMPAIGNREQUEST']._serialized_end=11786
  _globals['_QUERYTRADEREWARDCAMPAIGNRESPONSE']._serialized_start=11789
  _globals['_QUERYTRADEREWARDCAMPAIGNRESPONSE']._serialized_end=12411
  _globals['_QUERYISOPTEDOUTOFREWARDSREQUEST']._serialized_start=12413
  _globals['_QUERYISOPTEDOUTOFREWARDSREQUEST']._serialized_end=12472
  _globals['_QUERYISOPTEDOUTOFREWARDSRESPONSE']._serialized_start=12474
  _globals['_QUERYISOPTEDOUTOFREWARDSRESPONSE']._serialized_end=12542
  _globals['_QUERYOPTEDOUTOFREWARDSACCOUNTSREQUEST']._serialized_start=12544
  _globals['_QUERYOPTEDOUTOFREWARDSACCOUNTSREQUEST']._serialized_end=12583
  _globals['_QUERYOPTEDOUTOFREWARDSACCOUNTSRESPONSE']._serialized_start=12585
  _globals['_QUERYOPTEDOUTOFREWARDSACCOUNTSRESPONSE']._serialized_end=12653
  _globals['_QUERYFEEDISCOUNTACCOUNTINFOREQUEST']._serialized_start=12655
  _globals['_QUERYFEEDISCOUNTACCOUNTINFOREQUEST']._serialized_end=12717
  _globals['_QUERYFEEDISCOUNTACCOUNTINFORESPONSE']._serialized_start=12720
  _globals['_QUERYFEEDISCOUNTACCOUNTINFORESPONSE']._serialized_end=12943
  _globals['_QUERYFEEDISCOUNTSCHEDULEREQUEST']._serialized_start=12945
  _globals['_QUERYFEEDISCOUNTSCHEDULEREQUEST']._serialized_end=12978
  _globals['_QUERYFEEDISCOUNTSCHEDULERESPONSE']._serialized_start=12981
  _globals['_QUERYFEEDISCOUNTSCHEDULERESPONSE']._serialized_end=13111
  _globals['_QUERYBALANCEMISMATCHESREQUEST']._serialized_start=13113
  _globals['_QUERYBALANCEMISMATCHESREQUEST']._serialized_end=13177
  _globals['_BALANCEMISMATCH']._serialized_start=13180
  _globals['_BALANCEMISMATCH']._serialized_end=13598
  _globals['_QUERYBALANCEMISMATCHESRESPONSE']._serialized_start=13600
  _globals['_QUERYBALANCEMISMATCHESRESPONSE']._serialized_end=13719
  _globals['_QUERYBALANCEWITHBALANCEHOLDSREQUEST']._serialized_start=13721
  _globals['_QUERYBALANCEWITHBALANCEHOLDSREQUEST']._serialized_end=13758
  _globals['_BALANCEWITHMARGINHOLD']._serialized_start=13761
  _globals['_BALANCEWITHMARGINHOLD']._serialized_end=14040
  _globals['_QUERYBALANCEWITHBALANCEHOLDSRESPONSE']._serialized_start=14043
  _globals['_QUERYBALANCEWITHBALANCEHOLDSRESPONSE']._serialized_end=14188
  _globals['_QUERYFEEDISCOUNTTIERSTATISTICSREQUEST']._serialized_start=14190
  _globals['_QUERYFEEDISCOUNTTIERSTATISTICSREQUEST']._serialized_end=14229
  _globals['_TIERSTATISTIC']._serialized_start=14231
  _globals['_TIERSTATISTIC']._serialized_end=14288
  _globals['_QUERYFEEDISCOUNTTIERSTATISTICSRESPONSE']._serialized_start=14290
  _globals['_QUERYFEEDISCOUNTTIERSTATISTICSRESPONSE']._serialized_end=14400
  _globals['_MITOVAULTINFOSREQUEST']._serialized_start=14402
  _globals['_MITOVAULTINFOSREQUEST']._serialized_end=14425
  _globals['_MITOVAULTINFOSRESPONSE']._serialized_start=14428
  _globals['_MITOVAULTINFOSRESPONSE']._serialized_end=14624
  _globals['_QUERYMARKETIDFROMVAULTREQUEST']._serialized_start=14626
  _globals['_QUERYMARKETIDFROMVAULTREQUEST']._serialized_end=14694
  _globals['_QUERYMARKETIDFROMVAULTRESPONSE']._serialized_start=14696
  _globals['_QUERYMARKETIDFROMVAULTRESPONSE']._serialized_end=14757
  _globals['_QUERYHISTORICALTRADERECORDSREQUEST']._serialized_start=14759
  _globals['_QUERYHISTORICALTRADERECORDSREQUEST']._serialized_end=14824
  _globals['_QUERYHISTORICALTRADERECORDSRESPONSE']._serialized_start=14826
  _globals['_QUERYHISTORICALTRADERECORDSRESPONSE']._serialized_end=14937
  _globals['_TRADEHISTORYOPTIONS']._serialized_start=14940
  _globals['_TRADEHISTORYOPTIONS']._serialized_end=15123
  _globals['_QUERYMARKETVOLATILITYREQUEST']._serialized_start=15126
  _globals['_QUERYMARKETVOLATILITYREQUEST']._serialized_end=15281
  _globals['_QUERYMARKETVOLATILITYRESPONSE']._serialized_start=15284
  _globals['_QUERYMARKETVOLATILITYRESPONSE']._serialized_end=15538
  _globals['_QUERYBINARYMARKETSREQUEST']._serialized_start=15540
  _globals['_QUERYBINARYMARKETSREQUEST']._serialized_end=15591
  _globals['_QUERYBINARYMARKETSRESPONSE']._serialized_start=15593
  _globals['_QUERYBINARYMARKETSRESPONSE']._serialized_end=15691
  _globals['_QUERYTRADERDERIVATIVECONDITIONALORDERSREQUEST']._serialized_start=15693
  _globals['_QUERYTRADERDERIVATIVECONDITIONALORDERSREQUEST']._serialized_end=15806
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER']._serialized_start=15809
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER']._serialized_end=16223
  _globals['_QUERYTRADERDERIVATIVECONDITIONALORDERSRESPONSE']._serialized_start=16226
  _globals['_QUERYTRADERDERIVATIVECONDITIONALORDERSRESPONSE']._serialized_end=16356
  _globals['_QUERYFULLSPOTORDERBOOKREQUEST']._serialized_start=16358
  _globals['_QUERYFULLSPOTORDERBOOKREQUEST']._serialized_end=16418
  _globals['_QUERYFULLSPOTORDERBOOKRESPONSE']._serialized_start=16421
  _globals['_QUERYFULLSPOTORDERBOOKRESPONSE']._serialized_end=16577
  _globals['_QUERYFULLDERIVATIVEORDERBOOKREQUEST']._serialized_start=16579
  _globals['_QUERYFULLDERIVATIVEORDERBOOKREQUEST']._serialized_end=16645
  _globals['_QUERYFULLDERIVATIVEORDERBOOKRESPONSE']._serialized_start=16648
  _globals['_QUERYFULLDERIVATIVEORDERBOOKRESPONSE']._serialized_end=16810
  _globals['_TRIMMEDLIMITORDER']._serialized_start=16813
  _globals['_TRIMMEDLIMITORDER']._serialized_end=17024
  _globals['_QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERREQUEST']._serialized_start=17026
  _globals['_QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERREQUEST']._serialized_end=17103
  _globals['_QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERRESPONSE']._serialized_start=17105
  _globals['_QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERRESPONSE']._serialized_end=17223
  _globals['_QUERYACTIVESTAKEGRANTREQUEST']._serialized_start=17225
  _globals['_QUERYACTIVESTAKEGRANTREQUEST']._serialized_end=17281
  _globals['_QUERYACTIVESTAKEGRANTRESPONSE']._serialized_start=17284
  _globals['_QUERYACTIVESTAKEGRANTRESPONSE']._serialized_end=17453
  _globals['_QUERYGRANTAUTHORIZATIONREQUEST']._serialized_start=17455
  _globals['_QUERYGRANTAUTHORIZATIONREQUEST']._serialized_end=17539
  _globals['_QUERYGRANTAUTHORIZATIONRESPONSE']._serialized_start=17541
  _globals['_QUERYGRANTAUTHORIZATIONRESPONSE']._serialized_end=17629
  _globals['_QUERYGRANTAUTHORIZATIONSREQUEST']._serialized_start=17631
  _globals['_QUERYGRANTAUTHORIZATIONSREQUEST']._serialized_end=17690
  _globals['_QUERYGRANTAUTHORIZATIONSRESPONSE']._serialized_start=17693
  _globals['_QUERYGRANTAUTHORIZATIONSRESPONSE']._serialized_end=17871
  _globals['_QUERYMARKETBALANCEREQUEST']._serialized_start=17873
  _globals['_QUERYMARKETBALANCEREQUEST']._serialized_end=17929
  _globals['_QUERYMARKETBALANCERESPONSE']._serialized_start=17931
  _globals['_QUERYMARKETBALANCERESPONSE']._serialized_end=18023
  _globals['_QUERYMARKETBALANCESREQUEST']._serialized_start=18025
  _globals['_QUERYMARKETBALANCESREQUEST']._serialized_end=18053
  _globals['_QUERYMARKETBALANCESRESPONSE']._serialized_start=18055
  _globals['_QUERYMARKETBALANCESRESPONSE']._serialized_end=18150
  _globals['_MARKETBALANCE']._serialized_start=18152
  _globals['_MARKETBALANCE']._serialized_end=18259
  _globals['_QUERYDENOMMINNOTIONALREQUEST']._serialized_start=18261
  _globals['_QUERYDENOMMINNOTIONALREQUEST']._serialized_end=18313
  _globals['_QUERYDENOMMINNOTIONALRESPONSE']._serialized_start=18315
  _globals['_QUERYDENOMMINNOTIONALRESPONSE']._serialized_end=18407
  _globals['_QUERYDENOMMINNOTIONALSREQUEST']._serialized_start=18409
  _globals['_QUERYDENOMMINNOTIONALSREQUEST']._serialized_end=18440
  _globals['_QUERYDENOMMINNOTIONALSRESPONSE']._serialized_start=18442
  _globals['_QUERYDENOMMINNOTIONALSRESPONSE']._serialized_end=18563
  _globals['_QUERY']._serialized_start=18708
  _globals['_QUERY']._serialized_end=32120
# @@protoc_insertion_point(module_scope)
